@@ -46,6 +46,7 @@ from anyscale.client.openapi_client.models import (
     CloudDataBucketPresignedUrlResponse,
     CloudDataBucketPresignedUrlScheme,
     CloudNameOptions,
+    ClusteroperationResponse,
     ComputeTemplate,
     ComputeTemplateConfig,
     ComputeTemplateQuery,
@@ -60,12 +61,18 @@ from anyscale.client.openapi_client.models import (
     Dataset as InternalDataset,
     DatasetUpload,
     DecoratedComputeTemplate,
+    DecoratedjobqueueListResponse,
+    DecoratedlistserviceapimodelListResponse,
+    DecoratedProductionServiceV2APIModel,
     DecoratedSession,
     DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
     FineTunedModel,
     FinetunedmodelListResponse,
+    GetOrCreateBuildFromImageUriRequest,
     InternalProductionJob,
+    JobQueueSortDirective,
+    JobQueuesQuery,
     ListResourceQuotasQuery,
     OrganizationCollaborator,
     OrganizationInvitation,
@@ -73,19 +80,25 @@ from anyscale.client.openapi_client.models import (
     ResourceQuotaStatus,
     ServerSessionToken,
     SessionSshKey,
+    SessionState,
     StartSessionOptions,
     StopSessionOptions,
+    SystemWorkloadName,
     WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
+from anyscale.client.openapi_client.models.decorated_job_queue import DecoratedJobQueue
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
 from anyscale.client.openapi_client.models.production_job import ProductionJob
+from anyscale.client.openapi_client.models.update_job_queue_request import (
+    UpdateJobQueueRequest,
+)
 from anyscale.client.openapi_client.rest import ApiException as InternalApiException
 from anyscale.cluster_compute import parse_cluster_compute_name_version
 from anyscale.feature_flags import FLAG_DEFAULT_WORKING_DIR_FOR_PROJ
 from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as ExternalApi
 from anyscale.sdk.anyscale_client.models import (
-    ApplyServiceModel,
+    ApplyProductionServiceV2Model,
     Cluster,
     ClusterCompute,
     ClusterComputeConfig,
@@ -102,7 +115,6 @@ from anyscale.sdk.anyscale_client.models import (
     ProductionServiceV2VersionModel,
     Project,
     RollbackServiceModel,
-    ServiceModel,
     TextQuery,
 )
 from anyscale.sdk.anyscale_client.models.jobs_query import JobsQuery
@@ -250,6 +262,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         # Cached IDs and models to avoid duplicate lookups.
         self._default_project_id_from_cloud_id: Dict[Optional[str], str] = {}
         self._cloud_id_cache: Dict[Optional[str], str] = {}
+        self._cluster_env_build_cache: Dict[str, ClusterEnvironmentBuild] = {}
         self._current_workspace_cluster: Optional[Cluster] = None
         self._logger = logger or BlockLogger()
         self._host = host or ANYSCALE_HOST
@@ -428,7 +441,19 @@ class AnyscaleClient(AnyscaleClientInterface):
                 Defaults to `None`.
             name: The name of the project.
         """
-        # Find if project with name already exists
+        # First try to find project by name and parent cloud id
+        if parent_cloud_id is not None and name is not None:
+            response = self._external_api_client.search_projects(
+                {
+                    "name": {"equals": name,},
+                    "parent_cloud_id": {"equals": parent_cloud_id,},
+                }
+            )
+            if response.results:
+                # Project name is unique within a cloud, so we can just return the first result
+                return response.results[0].id
+
+        # Then find if project with name already exists
         matching_projects = self._internal_api_client.find_project_by_project_name_api_v2_projects_find_by_name_get(
             name
         ).results
@@ -468,12 +493,8 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         if self._default_project_id_from_cloud_id.get(parent_cloud_id) is None:
             # Cloud isolation organizations follow the permissions model in https://docs.anyscale.com/organization-and-user-account/access-controls
-            # TODO(nikita): Remove this FF check after completing the cloud isolation migration in Q2 2024
-            cloud_isolation_ff_on = self._internal_api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-                "cloud-isolation-phase-1"
-            ).result.is_on
             default_project: Project = self._external_api_client.get_default_project(
-                parent_cloud_id=(parent_cloud_id if cloud_isolation_ff_on else None)
+                parent_cloud_id=parent_cloud_id
             ).result
             self._default_project_id_from_cloud_id[parent_cloud_id] = default_project.id
 
@@ -546,9 +567,7 @@ class AnyscaleClient(AnyscaleClientInterface):
     @handle_api_exceptions
     def get_cloud(self, *, cloud_id: str) -> Optional[Cloud]:
         try:
-            cloud: Cloud = self._internal_api_client.get_cloud_api_v2_clouds_cloud_id_get(
-                cloud_id
-            ).result
+            cloud: Cloud = self._external_api_client.get_cloud(cloud_id=cloud_id).result
             return cloud
         except InternalApiException as e:
             if e.status == 404:
@@ -556,6 +575,21 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
+    def get_cloud_by_name(self, *, name) -> Optional[Cloud]:
+        cloud_id = self.get_cloud_id(cloud_name=name)
+        return self.get_cloud(cloud_id=cloud_id)
+
+    @handle_api_exceptions
+    def get_default_cloud(self) -> Optional[Cloud]:
+        try:
+            return self._external_api_client.get_default_cloud().result
+        except InternalApiException as e:
+            if e.status == 404:
+                return None
+
+            raise e from None
+
     @handle_api_exceptions
     def add_cloud_collaborators(
         self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
@@ -564,6 +598,19 @@ class AnyscaleClient(AnyscaleClientInterface):
             cloud_id, collaborators
         )
 
+    @handle_api_exceptions
+    def terminate_system_cluster(self, cloud_id: str) -> ClusteroperationResponse:
+        return self._internal_api_client.terminate_system_cluster_api_v2_system_workload_cloud_id_terminate_post(
+            cloud_id
+        )
+
+    @handle_api_exceptions
+    def describe_system_workload_get_status(self, cloud_id: str) -> str:
+        res = self._internal_api_client.describe_system_workload_api_v2_system_workload_cloud_id_describe_post(
+            cloud_id, SystemWorkloadName.RAY_OBS_EVENTS_API_SERVICE, start_cluster=False
+        ).result
+        return res.status
+
     @handle_api_exceptions
     def create_compute_config(
         self, config: ComputeTemplateConfig, *, name: Optional[str] = None
@@ -593,6 +640,7 @@ class AnyscaleClient(AnyscaleClientInterface):
     def get_compute_config_id(
         self,
         compute_config_name: Optional[str] = None,
+        cloud: Optional[str] = None,
         *,
         include_archived: bool = False,
     ) -> Optional[str]:
@@ -601,6 +649,11 @@ class AnyscaleClient(AnyscaleClientInterface):
             if version is None:
                 # Setting `version=-1` will return only the latest version if there are multiple.
                 version = -1
+
+            cloud_id = (
+                self.get_cloud_id(cloud_name=cloud) if cloud is not None else None
+            )
+
             cluster_computes = self._internal_api_client.search_compute_templates_api_v2_compute_templates_search_post(
                 ComputeTemplateQuery(
                     orgwide=True,
@@ -610,6 +663,7 @@ class AnyscaleClient(AnyscaleClientInterface):
                     if include_archived
                     else ArchiveStatus.NOT_ARCHIVED,
                     version=version,
+                    cloud_id=cloud_id,
                 )
             ).results
 
@@ -694,16 +748,41 @@ class AnyscaleClient(AnyscaleClientInterface):
 
     @handle_api_exceptions
     def get_cluster_env_build(self, build_id: str) -> Optional[ClusterEnvironmentBuild]:
-        return self._external_api_client.get_cluster_environment_build(build_id).result
+        # Check cache first
+        if build_id in self._cluster_env_build_cache:
+            return self._cluster_env_build_cache[build_id]
+
+        # Fetch from API if not in cache
+        try:
+            res = self._external_api_client.get_cluster_environment_build(build_id)
+            build = res.result
+        except ExternalApiException as e:
+            if e.status == 404:
+                return None
+
+            raise e from None
+
+        # Store in cache ONLY if the build exists and is in a terminal state
+        if build:
+            terminal_states = {
+                ClusterEnvironmentBuildStatus.SUCCEEDED,
+                ClusterEnvironmentBuildStatus.FAILED,
+                ClusterEnvironmentBuildStatus.CANCELED,
+            }
+            if build.status in terminal_states:
+                self._cluster_env_build_cache[build_id] = build
+
+        return build
 
     @handle_api_exceptions
     def get_cluster_env_build_image_uri(
         self, cluster_env_build_id: str, use_image_alias: bool = False
     ) -> Optional[ImageURI]:
         try:
-            build: ClusterEnvironmentBuild = self._external_api_client.get_cluster_environment_build(
-                cluster_env_build_id
-            ).result
+            build = self.get_cluster_env_build(cluster_env_build_id)
+            if build is None:
+                return None
+
             cluster_env = self._external_api_client.get_cluster_environment(
                 build.cluster_environment_id
             ).result
@@ -765,9 +844,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         """
         elapsed_secs = 0
         while elapsed_secs < timeout_secs:
-            build = self._external_api_client.get_cluster_environment_build(
-                build_id
-            ).result
+            build = self.get_cluster_env_build(build_id)
             if build.status == ClusterEnvironmentBuildStatus.SUCCEEDED:
                 self.logger.info("")
                 return
@@ -892,69 +969,15 @@ class AnyscaleClient(AnyscaleClientInterface):
         ray_version: Optional[str] = None,
         name: Optional[str] = None,
     ) -> str:
-        if image_uri.is_cluster_env_image():
-            identifier = image_uri.to_cluster_env_identifier()
-            try:
-                build = self._external_api_client.find_cluster_environment_build_by_identifier(
-                    identifier=identifier
-                ).result
-                if build.status == ClusterEnvironmentBuildStatus.SUCCEEDED:
-                    return build.id
-                else:
-                    raise RuntimeError(
-                        f"Legacy cluster environment build '{identifier}' is not a successful build."
-                    )
-            except ExternalApiException as e:
-                if e.status == 404:
-                    raise RuntimeError(
-                        f"Legacy cluster environment '{identifier}' is not found."
-                    )
-        elif image_uri.is_default_image():
-            # Default image
-            cluster_envs = self._internal_api_client.list_application_templates_api_v2_application_templates_get(
-                image_name_contains=image_uri.image_uri
-            ).results
-            for cluster_env in cluster_envs:
-                if (
-                    cluster_env.latest_build is not None
-                    and cluster_env.latest_build.docker_image_name
-                    == image_uri.image_uri
-                ):
-                    return cluster_env.latest_build.id
-            raise RuntimeError(f"Default image '{image_uri.image_uri}' is not found.")
-
-        # BYOD image
-        cluster_env_name = name if name else image_uri.to_cluster_env_name()
-        image_uri_str = str(image_uri)
-        cluster_env = self._find_or_create_cluster_env(
-            cluster_env_name,
-            anonymous=not name,
-            image_uri=image_uri_str,
-            registry_login_secret=registry_login_secret,
-            ray_version=ray_version,
-        )
-        for build in self.list_cluster_env_builds(cluster_env.id):
-            if (
-                build.docker_image_name == image_uri_str
-                and build.registry_login_secret == registry_login_secret
-                and build.status == ClusterEnvironmentBuildStatus.SUCCEEDED
-                and (ray_version is None or build.ray_version == ray_version)
-            ):
-                return build.id
-
-        # Still create a new build if the cluster env already exists but the build does not match the image_uri.
-        result = self._external_api_client.create_cluster_environment_build(
-            CreateClusterEnvironmentBuild(
-                # For historical reasons, we have to use docker_image_name instead of image_uri; but it is just a URI to the image.
-                cluster_environment_id=cluster_env.id,
-                docker_image_name=image_uri_str,
+        build = self._internal_api_client.get_or_create_build_from_image_uri_api_v2_builds_get_or_create_build_from_image_uri_post(
+            GetOrCreateBuildFromImageUriRequest(
+                image_uri=str(image_uri),
                 registry_login_secret=registry_login_secret,
-                ray_version=ray_version if ray_version else LATEST_RAY_VERSION,
+                ray_version=ray_version,
+                cluster_env_name=name,
             )
         ).result
-
-        assert result.completed
-        return result.cluster_environment_build_id
+        return build.id
 
     @handle_api_exceptions
     def send_workspace_notification(
@@ -974,31 +997,66 @@ class AnyscaleClient(AnyscaleClientInterface):
 
     @handle_api_exceptions
     def get_service(
-        self, name: str, *, cloud: Optional[str], project: Optional[str]
-    ) -> Optional[ServiceModel]:
-        # TODO(edoakes): this endpoint is very slow and there's no reason we should need
-        # to use this complex list endpoint just to fetch a service by name.
-        paging_token = None
-        cloud_id = self.get_cloud_id(cloud_name=cloud)
-        project_id = self.get_project_id(parent_cloud_id=cloud_id, name=project)
-        service: Optional[ServiceModel] = None
-        while True:
-            resp = self._external_api_client.list_services(
-                project_id=project_id,
-                name=name,
-                count=self.LIST_ENDPOINT_COUNT,
-                paging_token=paging_token,
-            )
-            for result in resp.results:
-                if result.name == name:
-                    service = result
-                    break
+        self,
+        name: str,
+        *,
+        cloud: Optional[str],
+        project: Optional[str],
+        include_archived: bool = False,
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
+        # we don't have an api to get a service by name, so we need to list services and filter by name
+        resp = self.list_services(
+            name=name, cloud=cloud, project=project, include_archived=include_archived
+        )
+        for result in resp.results:
+            if result.name == name:
+                return result
+        return None
 
-            paging_token = resp.metadata.next_paging_token
-            if service is not None or paging_token is None:
-                break
+    @handle_api_exceptions
+    def get_service_by_id(
+        self, service_id: str
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
+        return self._internal_api_client.get_service_api_v2_services_v2_service_id_get(
+            service_id
+        ).result
 
-        return service
+    @handle_api_exceptions
+    def list_services(
+        self,
+        *,
+        name: Optional[str] = None,
+        state_filter: Optional[List[str]] = None,
+        creator_id: Optional[str] = None,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+        include_archived: bool = False,
+        count: Optional[int] = None,
+        paging_token: Optional[str] = None,
+        sort_field: Optional[str] = None,
+        sort_order: Optional[str] = None,
+    ) -> DecoratedlistserviceapimodelListResponse:
+        cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
+        project_id = (
+            self.get_project_id(parent_cloud_id=cloud_id, name=project)
+            if project
+            else None
+        )
+
+        return self._internal_api_client.list_services_api_v2_services_v2_get(
+            project_id=project_id,
+            cloud_id=cloud_id,
+            name=name,
+            state_filter=state_filter,
+            creator_id=creator_id,
+            archive_status=ArchiveStatus.ALL
+            if include_archived
+            else ArchiveStatus.NOT_ARCHIVED,
+            count=count if count else self.LIST_ENDPOINT_COUNT,
+            paging_token=paging_token,
+            sort_field=sort_field,
+            sort_order=sort_order,
+        )
 
     @handle_api_exceptions
     def get_project(self, project_id: str) -> Optional[Project]:
@@ -1074,15 +1132,80 @@ class AnyscaleClient(AnyscaleClientInterface):
         return job_runs
 
     @handle_api_exceptions
-    def rollout_service(self, model: ApplyServiceModel) -> ServiceModel:
-        result: ServiceModel = self._external_api_client.rollout_service(model).result
+    def get_job_queue(self, job_queue_id: str) -> Optional[DecoratedJobQueue]:
+        try:
+            return self._internal_api_client.get_job_queue_api_v2_job_queues_job_queue_id_get(
+                job_queue_id
+            ).result
+        except InternalApiException as e:
+            if e.status == 404:
+                return None
+
+            raise e from None
+
+    @handle_api_exceptions
+    def update_job_queue(
+        self,
+        job_queue_id: str,
+        max_concurrency: Optional[int] = None,
+        idle_timeout_s: Optional[int] = None,
+    ) -> DecoratedJobQueue:
+        if max_concurrency is None and idle_timeout_s is None:
+            raise ValueError("No fields to update")
+
+        return self._internal_api_client.update_job_queue_api_v2_job_queues_job_queue_id_put(
+            job_queue_id,
+            update_job_queue_request=UpdateJobQueueRequest(
+                max_concurrency=max_concurrency, idle_timeout_sec=idle_timeout_s,
+            ),
+        ).result
+
+    @handle_api_exceptions
+    def list_job_queues(
+        self,
+        *,
+        name: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        cluster_status: Optional[SessionState] = None,
+        project: Optional[str] = None,
+        cloud: Optional[str] = None,
+        count: Optional[int] = None,
+        paging_token: Optional[str] = None,
+        sorting_directives: Optional[List[JobQueueSortDirective]] = None,
+    ) -> DecoratedjobqueueListResponse:
+        cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
+        project_id = (
+            self.get_project_id(parent_cloud_id=cloud_id, name=project)
+            if project
+            else None
+        )
+
+        return self._internal_api_client.list_job_queues_api_v2_job_queues_post(
+            job_queues_query=JobQueuesQuery(
+                name=name,
+                creator_id=creator_id,
+                cluster_status=cluster_status,
+                project_id=project_id,
+                cloud_id=cloud_id,
+                paging=PageQuery(count=count, paging_token=paging_token),
+                sorting_directives=sorting_directives,
+            ),
+        )
+
+    @handle_api_exceptions
+    def rollout_service(
+        self, model: ApplyProductionServiceV2Model
+    ) -> DecoratedProductionServiceV2APIModel:
+        result = self._internal_api_client.apply_service_api_v2_services_v2_apply_put(
+            model
+        ).result
         return result
 
     @handle_api_exceptions
     def rollback_service(
         self, service_id: str, *, max_surge_percent: Optional[int] = None
-    ) -> ServiceModel:
-        result: ServiceModel = self._external_api_client.rollback_service(
+    ) -> DecoratedProductionServiceV2APIModel:
+        result = self._internal_api_client.rollback_service_api_v2_services_v2_service_id_rollback_post(
             service_id,
             rollback_service_model=RollbackServiceModel(
                 max_surge_percent=max_surge_percent
@@ -1091,15 +1214,27 @@ class AnyscaleClient(AnyscaleClientInterface):
         return result
 
     @handle_api_exceptions
-    def terminate_service(self, service_id: str) -> ServiceModel:
-        result: ServiceModel = self._external_api_client.terminate_service(service_id)
+    def terminate_service(
+        self, service_id: str
+    ) -> DecoratedProductionServiceV2APIModel:
+        result = self._internal_api_client.terminate_service_api_v2_services_v2_service_id_terminate_post(
+            service_id
+        )
         return result
 
     @handle_api_exceptions
-    def archive_service(self, service_id: str) -> ServiceModel:
-        result: ServiceModel = self._external_api_client.archive_service(service_id)
+    def archive_service(self, service_id: str) -> DecoratedProductionServiceV2APIModel:
+        result = self._internal_api_client.archive_service_api_v2_services_v2_service_id_archive_post(
+            service_id
+        )
         return result
 
+    @handle_api_exceptions
+    def delete_service(self, service_id: str) -> None:
+        self._internal_api_client.delete_service_api_v2_services_v2_service_id_delete(
+            service_id
+        )
+
     @handle_api_exceptions
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         job: InternalProductionJob = self._internal_api_client.create_job_api_v2_decorated_ha_jobs_create_post(
@@ -1631,7 +1766,7 @@ class AnyscaleClient(AnyscaleClientInterface):
     def update_workspace(
         self,
         *,
-        workspace_id: str,
+        workspace_id: Optional[str],
         name: Optional[str] = None,
         compute_config_id: Optional[str] = None,
         cluster_environment_build_id: Optional[str] = None,
@@ -1723,7 +1858,9 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
 
     @handle_api_exceptions
-    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
+    def get_workspace_cluster(
+        self, workspace_id: Optional[str]
+    ) -> Optional[DecoratedSession]:
         workspace = self.get_workspace(id=workspace_id)
         if not workspace:
             raise ValueError(f"Workspace '{workspace_id}' not found.")
