@@ -8,6 +8,7 @@ from anyscale.client.openapi_client.models import (
     AdminCreateUser,
     AnyscaleServiceAccount,
     Cloud,
+    ClusteroperationResponse,
     ComputeTemplateConfig,
     CreateCloudCollaborator,
     CreateExperimentalWorkspace,
@@ -15,29 +16,34 @@ from anyscale.client.openapi_client.models import (
     CreateResourceQuota,
     CreateUserProjectCollaborator,
     DecoratedComputeTemplate,
+    DecoratedjobqueueListResponse,
+    DecoratedlistserviceapimodelListResponse,
+    DecoratedProductionServiceV2APIModel,
     DeletedPlatformFineTunedModel,
     FineTunedModel,
     InternalProductionJob,
+    JobQueueSortDirective,
     OrganizationCollaborator,
     OrganizationInvitation,
     Project,
     ResourceQuota,
     ServerSessionToken,
+    SessionState,
     WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
+from anyscale.client.openapi_client.models.decorated_job_queue import DecoratedJobQueue
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
 from anyscale.client.openapi_client.models.decorated_session import DecoratedSession
 from anyscale.client.openapi_client.models.production_job import ProductionJob
 from anyscale.client.openapi_client.models.session_ssh_key import SessionSshKey
 from anyscale.sdk.anyscale_client.models import (
-    ApplyServiceModel,
+    ApplyProductionServiceV2Model,
     Cluster,
     ClusterCompute,
     ClusterEnvironment,
     Job as APIJobRun,
     ProductionServiceV2VersionModel,
-    ServiceModel,
 )
 from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
     ClusterEnvironmentBuild,
@@ -49,7 +55,7 @@ from anyscale.utils.workspace_notification import WorkspaceNotification
 # Maybe just make it part of the release process to update it, or fetch the
 # default builds and get the latest one. The best thing to do is probably
 # to populate this in the backend.
-DEFAULT_RAY_VERSION = "2.41.0"  # RAY_RELEASE_UPDATE: update to latest version.
+DEFAULT_RAY_VERSION = "2.47.1"  # RAY_RELEASE_UPDATE: update to latest version.
 DEFAULT_PYTHON_VERSION = "py311"
 RUNTIME_ENV_PACKAGE_FORMAT = "pkg_{content_hash}.zip"
 
@@ -150,6 +156,19 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def get_cloud_by_name(self, *, name: str) -> Optional[Cloud]:
+        """Get the cloud model for the provided cloud name.
+
+        Returns `None` if the cloud name was not found.
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def get_default_cloud(self) -> Optional[Cloud]:
+        """Get the user's default cloud."""
+        raise NotImplementedError
+
     @abstractmethod
     def add_cloud_collaborators(
         self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
@@ -157,6 +176,16 @@ class AnyscaleClientInterface(ABC):
         """Batch add collaborators to a cloud."""
         raise NotImplementedError
 
+    @abstractmethod
+    def terminate_system_cluster(self, cloud_id: str) -> ClusteroperationResponse:
+        """Terminate the system cluster for the provided cloud ID."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def describe_system_workload_get_status(self, cloud_id: str) -> str:
+        """Get the status of the system cluster for the provided cloud ID."""
+        raise NotImplementedError
+
     @abstractmethod
     def create_compute_config(
         self, config: ComputeTemplateConfig, *, name: Optional[str] = None
@@ -171,7 +200,11 @@ class AnyscaleClientInterface(ABC):
 
     @abstractmethod
     def get_compute_config_id(
-        self, compute_config_name: Optional[str] = None, *, include_archived=False
+        self,
+        compute_config_name: Optional[str] = None,
+        cloud: Optional[str] = None,
+        *,
+        include_archived=False,
     ) -> Optional[str]:
         """Get the compute config ID for the provided name.
 
@@ -284,14 +317,44 @@ class AnyscaleClientInterface(ABC):
 
     @abstractmethod
     def get_service(
-        self, name: str, *, cloud: Optional[str], project: Optional[str]
-    ) -> Optional[ServiceModel]:
+        self,
+        name: str,
+        *,
+        cloud: Optional[str],
+        project: Optional[str],
+        include_archived=False,
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
         """Get a service by name. Filter by cloud and project.
 
         Returns None if not found.
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def get_service_by_id(
+        self, service_id: str
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
+        """Get a service by id."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def list_services(
+        self,
+        *,
+        name: Optional[str],
+        state_filter: Optional[List[str]],
+        creator_id: Optional[str],
+        cloud: Optional[str],
+        project: Optional[str],
+        include_archived: bool,
+        count: Optional[int],
+        paging_token: Optional[str],
+        sort_field: Optional[str],
+        sort_order: Optional[str],
+    ) -> DecoratedlistserviceapimodelListResponse:
+        """List services."""
+        raise NotImplementedError
+
     @abstractmethod
     def get_project(self, project_id: str) -> Optional[Project]:
         """Get a project by id.
@@ -322,6 +385,24 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def get_job_queue(self, job_queue_id: str) -> Optional[DecoratedJobQueue]:
+        """Get a job queue by id.
+
+        Returns None if not found.
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def update_job_queue(
+        self,
+        job_queue_id: str,
+        max_concurrency: Optional[int] = None,
+        idle_timeout_s: Optional[int] = None,
+    ) -> DecoratedJobQueue:
+        """Update a job queue."""
+        raise NotImplementedError
+
     @abstractmethod
     def get_job_runs(self, job_id: str) -> List[APIJobRun]:
         """Returns all job runs for a given job id.
@@ -331,7 +412,25 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def rollout_service(self, model: ApplyServiceModel) -> ServiceModel:
+    def list_job_queues(
+        self,
+        *,
+        name: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        cluster_status: Optional[SessionState] = None,
+        project: Optional[str] = None,
+        cloud: Optional[str] = None,
+        count: Optional[int] = None,
+        paging_token: Optional[str] = None,
+        sorting_directives: Optional[List[JobQueueSortDirective]] = None,
+    ) -> DecoratedjobqueueListResponse:
+        """List job queues."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def rollout_service(
+        self, model: ApplyProductionServiceV2Model
+    ) -> DecoratedProductionServiceV2APIModel:
         """Deploy or update the service to use the provided config.
 
         Returns the service ID.
@@ -349,15 +448,22 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def terminate_service(self, service_id: str):
+    def terminate_service(
+        self, service_id: str
+    ) -> DecoratedProductionServiceV2APIModel:
         """Mark the service to be terminated asynchronously."""
         raise NotImplementedError
 
     @abstractmethod
-    def archive_service(self, service_id: str):
+    def archive_service(self, service_id: str) -> DecoratedProductionServiceV2APIModel:
         """Mark the service to be archived asynchronously."""
         raise NotImplementedError
 
+    @abstractmethod
+    def delete_service(self, service_id: str) -> None:
+        """Mark the service to be deleted asynchronously."""
+        raise NotImplementedError
+
     @abstractmethod
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         """Submit the job to run."""
@@ -538,14 +644,14 @@ class AnyscaleClientInterface(ABC):
 
     @abstractmethod
     def update_workspace_dependencies_offline_only(
-        self, workspace_id: str, requirements: List[str]
+        self, workspace_id: Optional[str], requirements: List[str]
     ):
         """Updates the dynamic dependencies of a workspace while the workspace is offline"""
         raise NotImplementedError
 
     @abstractmethod
     def update_workspace_env_vars_offline_only(
-        self, workspace_id: str, env_vars: Dict[str, str]
+        self, workspace_id: Optional[str], env_vars: Dict[str, str]
     ):
         """Updates the dynamic dependencies of a workspace"""
         raise NotImplementedError
@@ -558,7 +664,9 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
+    def get_workspace_cluster(
+        self, workspace_id: Optional[str]
+    ) -> Optional[DecoratedSession]:
         """Get the cluster model for the provided workspace ID."""
         raise NotImplementedError
 
@@ -599,7 +707,7 @@ class AnyscaleClientInterface(ABC):
     def update_workspace(
         self,
         *,
-        workspace_id: str,
+        workspace_id: Optional[str] = None,  # noqa: A002
         name: Optional[str] = None,
         compute_config_id: Optional[str] = None,
         cluster_environment_build_id: Optional[str] = None,
