@@ -19,6 +19,9 @@ from anyscale.client.openapi_client.models import (
     AnyscaleServiceAccount,
     Cloud,
     CloudProviders,
+    ClusterOperation,
+    ClusteroperationResponse,
+    ClusterState,
     ComputeTemplateConfig,
     CreateCloudCollaborator,
     CreateExperimentalWorkspace,
@@ -26,6 +29,8 @@ from anyscale.client.openapi_client.models import (
     CreateResourceQuota,
     CreateUserProjectCollaborator,
     DecoratedComputeTemplate,
+    DecoratedlistserviceapimodelListResponse,
+    DecoratedProductionServiceV2APIModel,
     DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
     FineTunedModel,
@@ -33,6 +38,7 @@ from anyscale.client.openapi_client.models import (
     HaJobGoalStates,
     HaJobStates,
     InternalProductionJob,
+    ListResponseMetadata,
     MiniCloud,
     MiniUser,
     OrganizationCollaborator,
@@ -46,6 +52,7 @@ from anyscale.client.openapi_client.models import (
     WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
+from anyscale.client.openapi_client.models.decorated_job_queue import DecoratedJobQueue
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
 from anyscale.client.openapi_client.models.decorated_session import DecoratedSession
 from anyscale.client.openapi_client.models.session_ssh_key import SessionSshKey
@@ -53,7 +60,7 @@ from anyscale.cluster_compute import parse_cluster_compute_name_version
 from anyscale.llm.dataset._private.models import Dataset
 from anyscale.sdk.anyscale_client.configuration import Configuration
 from anyscale.sdk.anyscale_client.models import (
-    ApplyServiceModel,
+    ApplyProductionServiceV2Model,
     Cluster,
     ClusterCompute,
     ClusterComputeConfig,
@@ -63,7 +70,6 @@ from anyscale.sdk.anyscale_client.models import (
     Job as APIJobRun,
     ProductionServiceV2VersionModel,
     ServiceEventCurrentState,
-    ServiceModel,
     ServiceVersionState,
     SessionState,
 )
@@ -143,13 +149,15 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self._archived_compute_configs: Dict[str, ClusterCompute] = {}
         self._workspace_cluster: Optional[Cluster] = None
         self._workspace_dependency_tracking_enabled: bool = False
-        self._services: Dict[str, ServiceModel] = {}
-        self._archived_services: Dict[str, ServiceModel] = {}
+        self._services: Dict[str, DecoratedProductionServiceV2APIModel] = {}
+        self._archived_services: Dict[str, DecoratedProductionServiceV2APIModel] = {}
+        self._deleted_services: Dict[str, DecoratedProductionServiceV2APIModel] = {}
         self._jobs: Dict[str, ProductionJob] = {}
         self._job_runs: Dict[str, List[APIJobRun]] = defaultdict(list)
+        self._job_queues: Dict[str, DecoratedJobQueue] = {}
         self._project_to_id: Dict[Optional[str] : Dict[Optional[str], str]] = {}
         self._project_collaborators: Dict[str, List[CreateUserProjectCollaborator]] = {}
-        self._rolled_out_model: Optional[ApplyServiceModel] = None
+        self._rolled_out_model: Optional[ApplyProductionServiceV2Model] = None
         self._sent_workspace_notifications: List[WorkspaceNotification] = []
         self._rolled_back_service: Optional[Tuple[str, Optional[int]]] = None
         self._terminated_service: Optional[str] = None
@@ -172,6 +180,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self._organization_collaborators: List[OrganizationCollaborator] = []
         self._organization_invitations: Dict[str, OrganizationInvitation] = {}
         self._resource_quotas: Dict[str, ResourceQuota] = {}
+        self._system_cluster_status: Dict[str, str] = {}
 
         # Cloud ID -> Cloud.
         self._clouds: Dict[str, Cloud] = {
@@ -364,10 +373,20 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
 
     def add_cloud(self, cloud: Cloud):
         self._clouds[cloud.id] = cloud
+        self._system_cluster_status[cloud.id] = ClusterState.RUNNING
 
     def get_cloud(self, *, cloud_id: str) -> Optional[Cloud]:
         return self._clouds.get(cloud_id, None)
 
+    def get_cloud_by_name(self, *, name: str) -> Optional[Cloud]:
+        for c in self._clouds.values():
+            if c.name == name:
+                return c
+        return None
+
+    def get_default_cloud(self) -> Optional[Cloud]:
+        return self._clouds.get(self.DEFAULT_CLOUD_ID, None)
+
     def add_cloud_collaborators(
         self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
     ) -> None:
@@ -387,6 +406,25 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         else:
             self._cloud_collaborators[cloud_id].extend(collaborators)
 
+    def terminate_system_cluster(
+        self, cloud_id: str
+    ) -> Optional[ClusteroperationResponse]:
+        self._system_cluster_status[cloud_id] = ClusterState.TERMINATING
+        return ClusteroperationResponse(
+            result=ClusterOperation(
+                id="sop_123",
+                completed=False,
+                progress=None,
+                result=None,
+                cluster_id="fake-system-cluster-id",
+                cluster_operation_type="terminate",
+            )
+        )
+
+    def describe_system_workload_get_status(self, cloud_id: str) -> str:
+        self._system_cluster_status[cloud_id] = ClusterState.TERMINATED
+        return self._system_cluster_status[cloud_id]
+
     def add_compute_config(self, compute_config: DecoratedComputeTemplate) -> int:
         compute_config.version = (
             len(self._compute_config_name_to_ids[compute_config.name]) + 1
@@ -430,7 +468,11 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         return None
 
     def get_compute_config_id(
-        self, compute_config_name: Optional[str] = None, *, include_archived=False
+        self,
+        compute_config_name: Optional[str] = None,
+        cloud: Optional[str] = None,
+        *,
+        include_archived=False,
     ) -> Optional[str]:
         if compute_config_name is not None:
             name, version = parse_cluster_compute_name_version(compute_config_name)
@@ -453,7 +495,8 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         if workspace_cluster is not None:
             return workspace_cluster.cluster_compute_id
 
-        return self.get_default_compute_config(cloud_id=self.get_cloud_id()).id
+        cloud_id = self.get_cloud_id(cloud_name=cloud)
+        return self.get_default_compute_config(cloud_id=cloud_id).id
 
     def archive_compute_config(self, *, compute_config_id: str):
         archived_config = self._compute_configs.pop(compute_config_id)
@@ -588,12 +631,17 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
                 cluster_env = self._images[build.cluster_environment_id]
                 return ImageURI.from_cluster_env_build(cluster_env, build)
 
-    def update_service(self, model: ServiceModel):
+    def update_service(self, model: DecoratedProductionServiceV2APIModel):
         self._services[model.id] = model
 
     def get_service(
-        self, name: str, *, cloud: Optional[str], project: Optional[str]
-    ) -> Optional[ServiceModel]:
+        self,
+        name: str,
+        *,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+        include_archived: bool = False,
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
         cloud_id = self.get_cloud_id(cloud_name=cloud)
         cloud_project_dict = self._project_to_id.get(cloud_id, None)
         project_id = (
@@ -605,6 +653,13 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             ):
                 return service
 
+        if include_archived:
+            for service in self._archived_services.values():
+                if service.name == name and (
+                    project_id is None or service.project_id == project_id
+                ):
+                    return service
+
         return None
 
     def get_project(self, project_id: str) -> Optional[Project]:
@@ -678,8 +733,20 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
     def update_job_run(self, prod_job_id: str, model: APIJobRun):
         self._job_runs[prod_job_id].append(model)
 
+    def list_job_queues(self) -> List[DecoratedJobQueue]:
+        return list(self._job_queues.values())
+
+    def get_job_queue(self, job_queue_id: str) -> Optional[DecoratedJobQueue]:
+        return self._job_queues.get(job_queue_id, None)
+
+    def update_job_queue(self, model: DecoratedJobQueue):
+        self._job_queues[model.id] = model
+
     def register_project_by_name(
-        self, name: str, cloud: str = DEFAULT_CLOUD_NAME, project_id: str = None
+        self,
+        name: str,
+        cloud: str = DEFAULT_CLOUD_NAME,
+        project_id: Optional[str] = None,
     ) -> str:
         """Helper method to create project name to project id mapping."""
         cloud_id = self.get_cloud_id(cloud_name=cloud)
@@ -695,10 +762,12 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             return project_id
 
     @property
-    def rolled_out_model(self) -> Optional[ApplyServiceModel]:
+    def rolled_out_model(self) -> Optional[ApplyProductionServiceV2Model]:
         return self._rolled_out_model
 
-    def rollout_service(self, model: ApplyServiceModel) -> ServiceModel:
+    def rollout_service(
+        self, model: ApplyProductionServiceV2Model
+    ) -> DecoratedProductionServiceV2APIModel:
         self._rolled_out_model = model
         # TODO(mowen): This feels convoluted, is there a better way to pull cloud name and project name from the model?
         project_model = self.get_project(model.project_id)
@@ -713,18 +782,17 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         else:
             service_id = f"service-id-{uuid.uuid4()!s}"
 
-        service = ServiceModel(
+        service = DecoratedProductionServiceV2APIModel(
             id=service_id,
             name=model.name,
-            current_state=ServiceEventCurrentState.RUNNING,
-            cloud_id=cloud_id,
             project_id=model.project_id,
-            base_url="http://fake-service-url",
-            auth_token="fake-auth-token"
-            if model.config.access.use_bearer_token
-            else None,
+            cloud_id=self.get_cloud_id(compute_config_id=model.compute_config_id),
+            current_state=ServiceEventCurrentState.STARTING,
+            base_url=f"http://{model.name}.fake.url",
+            auth_token="fake-auth-token",
             primary_version=ProductionServiceV2VersionModel(
                 id=str(uuid.uuid4()),
+                created_at=datetime.now(),
                 version="primary",
                 current_state=ServiceVersionState.RUNNING,
                 weight=100,
@@ -736,10 +804,13 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             ),
             local_vars_configuration=OPENAPI_NO_VALIDATION,
         )
-
         self.update_service(service)
         return service
 
+    @property
+    def submitted_job(self) -> Optional[CreateInternalProductionJob]:
+        return self._submitted_job
+
     @property
     def rolled_back_service(self) -> Optional[Tuple[str, Optional[int]]]:
         return self._rolled_back_service
@@ -765,18 +836,18 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             ].primary_version.current_state = ServiceVersionState.TERMINATED
 
     @property
-    def archived_services(self) -> Dict[str, ServiceModel]:
+    def archived_services(self) -> Dict[str, DecoratedProductionServiceV2APIModel]:
         return self._archived_services
 
     def archive_service(self, service_id: str):
         self._archived_services[service_id] = self._services.pop(service_id)
 
-    def is_archived_service(self, service_id: str) -> bool:
-        return service_id in self._archived_services
-
     @property
-    def submitted_job(self) -> Optional[CreateInternalProductionJob]:
-        return self._submitted_job
+    def deleted_services(self) -> Dict[str, DecoratedProductionServiceV2APIModel]:
+        return self._deleted_services
+
+    def delete_service(self, service_id: str):
+        self._deleted_services[service_id] = self._services.pop(service_id)
 
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         self._submitted_job = model
@@ -1037,17 +1108,23 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         workspace.state = SessionState.TERMINATED
 
     def update_workspace_dependencies_offline_only(
-        self, workspace_id: str, requirements: List[str]
+        self, workspace_id: Optional[str], requirements: List[str]
     ):
+        assert workspace_id is not None
         self._workspaces_dependencies[workspace_id] = requirements
 
     def update_workspace_env_vars_offline_only(
-        self, workspace_id: str, env_vars: Dict[str, str]
+        self, workspace_id: Optional[str], env_vars: Dict[str, str]
     ):
+        assert workspace_id is not None
         self._workspaces_env_vars[workspace_id] = env_vars
 
-    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
-        workspace_model = self._workspaces.get(workspace_id, None)
+    def get_workspace_cluster(
+        self, workspace_id: Optional[str]
+    ) -> Optional[DecoratedSession]:
+        workspace_model = (
+            self._workspaces.get(workspace_id, None) if workspace_id else None
+        )
         compute_config = self.get_compute_config(workspace_model.compute_config_id)
         assert compute_config is not None
         return Mock(
@@ -1076,7 +1153,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         return self._clusters_headnode_ip.get(cluster_id, "")
 
     def get_cluster_ssh_key(self, cluster_id: str) -> SessionSshKey:
-        return self._clusters_ssh_key.get(cluster_id, None)
+        return self._clusters_ssh_key.get(cluster_id, None)  # type: ignore
 
     def get_workspace_default_dir_name(self, workspace_id) -> str:
         workspace = self._workspaces.get(workspace_id, None)
@@ -1110,7 +1187,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
     def update_workspace(
         self,
         *,
-        workspace_id: str,
+        workspace_id: Optional[str] = None,  # noqa: A002
         name: Optional[str] = None,
         compute_config_id: Optional[str] = None,
         cluster_environment_build_id: Optional[str] = None,
@@ -1344,3 +1421,72 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             raise ValueError(f"Resource Quota with id '{resource_quota_id}' not found.")
 
         resource_quota.is_enabled = is_enabled
+
+    def get_service_by_id(
+        self, service_id: str
+    ) -> Optional[DecoratedProductionServiceV2APIModel]:
+        if service_id in self._services:
+            return self._services[service_id]
+        if service_id in self._archived_services:
+            return self._archived_services[service_id]
+        if service_id in self._deleted_services:
+            return self._deleted_services[service_id]
+        return None
+
+    def list_services(
+        self,
+        *,
+        name: Optional[str] = None,
+        state_filter: Optional[List[str]] = None,
+        creator_id: Optional[str] = None,  # noqa: ARG002
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+        include_archived: bool = False,
+        count: Optional[int] = None,
+        paging_token: Optional[str] = None,  # noqa: ARG002
+        sort_field: Optional[str] = None,  # noqa: ARG002
+        sort_order: Optional[str] = None,  # noqa: ARG002
+    ) -> DecoratedlistserviceapimodelListResponse:
+        target_services = list(self._services.values())
+        if include_archived:
+            target_services.extend(list(self._archived_services.values()))
+
+        target_cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
+        target_project_id = (
+            self.get_project_id(parent_cloud_id=target_cloud_id, name=project)
+            if project
+            else None
+        )
+
+        filtered_results = []
+        for svc in target_services:
+            if name is not None and svc.name != name:
+                continue
+            # Ensure state comparison works whether svc.current_state is Enum or str
+            current_state_str = (
+                svc.current_state.value
+                if hasattr(svc.current_state, "value")
+                else svc.current_state
+            )
+            if state_filter is not None and current_state_str not in state_filter:
+                continue
+            if target_project_id is not None and svc.project_id != target_project_id:
+                continue
+            if target_cloud_id is not None and svc.cloud_id != target_cloud_id:
+                continue
+
+            filtered_results.append(svc)
+
+        if count is None:
+            count = len(filtered_results)
+        final_results = filtered_results[:count]
+
+        response = DecoratedlistserviceapimodelListResponse(
+            results=final_results,
+            metadata=ListResponseMetadata(
+                total=len(final_results),
+                next_paging_token=None,  # Fake doesn't support paging
+            ),
+            local_vars_configuration=OPENAPI_NO_VALIDATION,
+        )
+        return response
