@@ -11,7 +11,10 @@ from anyscale import scripts
 from anyscale._private.docgen.generator import MarkdownGenerator, Module
 from anyscale.aggregated_instance_usage.models import DownloadCSVFilters
 from anyscale.cloud.models import (
+    Cloud,
     CloudPermissionLevel,
+    CloudProvider,
+    ComputeStack,
     CreateCloudCollaborator,
 )
 from anyscale.commands import (
@@ -116,7 +119,6 @@ ALL_MODULES = [
             "get_default_project": None,
             "get_project": None,
             "search_projects": None,
-            "update_project": None,
         },
         legacy_sdk_models=[
             "CreateProject",
@@ -124,7 +126,6 @@ ALL_MODULES = [
             "ProjectListResponse",
             "ProjectResponse",
             "ProjectsQuery",
-            "UpdateProject",
         ],
     ),
     Module(
@@ -164,7 +165,6 @@ ALL_MODULES = [
         legacy_sdk_commands={
             "create_job": anyscale.job.submit,
             "get_production_job": anyscale.job.status,
-            "get_session_for_job": anyscale.job.status,
             "terminate_job": anyscale.job.terminate,
             "fetch_job_logs": anyscale.job.get_logs,
             "fetch_production_job_logs": anyscale.job.get_logs,
@@ -230,7 +230,7 @@ ALL_MODULES = [
             "list_schedules": None,
         },
         legacy_cli_prefix="anyscale schedule",
-        legacy_cli_commands={schedule_commands.create, schedule_commands.update,},
+        legacy_cli_commands=[schedule_commands.create, schedule_commands.update],
     ),
     Module(
         title="Service",
@@ -242,6 +242,8 @@ ALL_MODULES = [
             service_commands.wait,
             service_commands.rollback,
             service_commands.terminate,
+            service_commands.archive,
+            service_commands.delete,
         ],
         sdk_prefix="anyscale.service",
         sdk_commands=[
@@ -250,6 +252,8 @@ ALL_MODULES = [
             anyscale.service.wait,
             anyscale.service.rollback,
             anyscale.service.terminate,
+            anyscale.service.archive,
+            anyscale.service.delete,
         ],
         models=[
             ServiceConfig,
@@ -291,7 +295,7 @@ ALL_MODULES = [
             "ServicemodelResponse",
         ],
         legacy_cli_prefix="anyscale service",
-        legacy_cli_commands={service_commands.rollout},
+        legacy_cli_commands=[service_commands.rollout],
     ),
     Module(
         title="Compute Config",
@@ -333,16 +337,10 @@ ALL_MODULES = [
             "ComputeNodeType",
             "ComputeTemplate",
             "ComputeTemplateConfig",
-            "ComputeTemplateQuery",
-            "ComputetemplateListResponse",
             "ComputetemplateResponse",
             "ComputetemplateconfigResponse",
             "CreateClusterCompute",
             "CreateClusterComputeConfig",
-            "CreateComputeTemplate",
-            "CreateComputeTemplateConfig",
-            "UpdateComputeTemplate",
-            "UpdateComputeTemplateConfig",
         ],
     ),
     Module(
@@ -384,38 +382,33 @@ ALL_MODULES = [
         models=[ImageBuild, ImageBuildStatus],
         legacy_title="Cluster environment",
         legacy_cli_prefix="anyscale image",
-        legacy_cli_commands={
+        legacy_cli_commands=[
             cluster_env_commands.archive,
             cluster_env_commands.build,
             cluster_env_commands.get,
             cluster_env_commands.list,
-        },
+        ],
         legacy_sdk_commands={
-            "get_cluster_environment_build_operation": None,
             "create_byod_cluster_environment_build": anyscale.image.build,
             "create_cluster_environment_build": anyscale.image.build,
             "find_cluster_environment_build_by_identifier": None,
             "get_cluster_environment_build": None,
-            "get_cluster_environment_build_logs": None,
             "get_default_cluster_environment_build": None,
             "list_cluster_environment_builds": None,
             "create_byod_cluster_environment": anyscale.image.build,
             "create_cluster_environment": anyscale.image.build,
-            "delete_cluster_environment": None,
             "get_cluster_environment": None,
             "search_cluster_environments": None,
         },
         legacy_sdk_models=[
             "ClusterEnvironment",
             "ClusterEnvironmentBuild",
-            "ClusterEnvironmentBuildLogResponse",
             "ClusterEnvironmentBuildOperation",
             "ClusterEnvironmentBuildStatus",
             "ClusterEnvironmentsQuery",
             "ClusterenvironmentListResponse",
             "ClusterenvironmentResponse",
             "ClusterenvironmentbuildListResponse",
-            "ClusterenvironmentbuildlogresponseResponse",
             "ClusterenvironmentbuildoperationResponse",
             "CreateBYODClusterEnvironment",
             "CreateBYODClusterEnvironmentBuild",
@@ -424,8 +417,6 @@ ALL_MODULES = [
             "CreateClusterEnvironmentBuild",
             "CreateClusterEnvironmentConfigurationSchema",
             "RayRuntimeEnvConfig",
-            "RuntimeEnvironment",
-            "RuntimeenvironmentResponse",
         ],
     ),
     Module(
@@ -443,19 +434,30 @@ ALL_MODULES = [
             cloud_commands.cloud_config_update,
             cloud_commands.cloud_set_default,
             cloud_commands.add_collaborators,
+            cloud_commands.get_cloud,
+            cloud_commands.get_default_cloud,
+            cloud_commands.terminate_system_cluster,
         ],
         sdk_prefix="anyscale.cloud",
-        sdk_commands=[anyscale.cloud.add_collaborators],
-        models=[CloudPermissionLevel, CreateCloudCollaborator],
+        sdk_commands=[
+            anyscale.cloud.add_collaborators,
+            anyscale.cloud.get,
+            anyscale.cloud.get_default,
+            anyscale.cloud.terminate_system_cluster,
+        ],
+        models=[
+            CloudPermissionLevel,
+            CreateCloudCollaborator,
+            Cloud,
+            ComputeStack,
+            CloudProvider,
+        ],
         cli_command_group_prefix={cloud_commands.cloud_config_update: "config"},
         legacy_sdk_commands={
             # limited support, no replacement yet
-            "create_cloud": None,
-            "delete_cloud": None,
             "get_cloud": None,
             "get_default_cloud": None,
             "search_clouds": None,
-            "update_cloud": None,
         },
         legacy_sdk_models=[
             "Cloud",
@@ -468,8 +470,6 @@ ALL_MODULES = [
             "CloudTypes",
             "CloudVersion",
             "CloudsQuery",
-            "CreateCloud",
-            "UpdateCloud",
         ],
     ),
     Module(
@@ -529,8 +529,12 @@ ALL_MODULES = [
         cli_prefix="anyscale machine-pool",
         cli_commands=[
             machine_pool_commands.create_machine_pool,
+            machine_pool_commands.update_machine_pool,
             machine_pool_commands.delete_machine_pool,
+            machine_pool_commands.attach_machine_pool_to_cloud,
+            machine_pool_commands.detach_machine_pool_from_cloud,
             machine_pool_commands.list_machine_pools,
+            machine_pool_commands.describe,
         ],
         sdk_prefix="anyscale.machine_pool",
         sdk_commands=[],
@@ -549,7 +553,6 @@ ALL_MODULES = [
         legacy_sdk_commands={
             "launch_cluster": None,
             "launch_cluster_with_new_cluster_environment": None,
-            "archive_cluster": None,
             "create_cluster": None,
             "delete_cluster": None,
             "get_cluster": None,
@@ -667,12 +670,7 @@ ALL_MODULES = [
             machine_commands.list_machines,
         ],
         legacy_sdk_commands={
-            "get_organization_temporary_object_storage_credentials": None,
             "partial_update_organization": None,
-            "get_runtime_environment": None,
-            "create_session_command": None,
-            "get_session_command": None,
-            "list_session_commands": None,
             "upsert_sso_config": None,
             "upsert_test_sso_config": None,
         },
@@ -682,10 +680,8 @@ ALL_MODULES = [
             "BASEIMAGESENUM",
             "BaseJobStatus",
             "Build",
-            "BuildListResponse",
             "BuildResponse",
             "BuildStatus",
-            "CreateBuild",
             "CreateSSOConfig",
             "GrpcProtocolConfig",
             "HTTPValidationError",
@@ -693,9 +689,6 @@ ALL_MODULES = [
             "IdleTerminationStatus",
             "ListResponseMetadata",
             "NodeType",
-            "ObjectStorageConfig",
-            "ObjectStorageConfigS3",
-            "ObjectstorageconfigResponse",
             "OperationError",
             "OperationProgress",
             "OperationResult",
