@@ -60,7 +60,7 @@ class Module:
     legacy_title: Optional[str] = None
     legacy_cli_prefix: Optional[str] = None
     legacy_cli_commands: Optional[List[LegacyAnyscaleCommand]] = None
-    legacy_sdk_commands: Optional[Dict[str, Callable]] = None
+    legacy_sdk_commands: Optional[Dict[str, Optional[Callable]]] = None
     legacy_sdk_models: Optional[List[str]] = None
 
 
@@ -259,7 +259,7 @@ class MarkdownGenerator:
         if typing.get_origin(t) is not None:
             return self._type_container_to_string(t)
         if isinstance(t, (ModelBaseType, ModelEnumType)):
-            return f"[{t.__name__}]({self._get_anchor(t)})"
+            return f"[{t.__name__}]({self._get_anchor(t)})"  # type: ignore
 
         # Avoid poor rendering of unhandled types.
         raise NotImplementedError(
