@@ -117,6 +117,7 @@ class WorkloadSDK(BaseSDK):
         cloud_id: Optional[str] = None,
         autopopulate_in_workspace: bool = True,
         additional_py_modules: Optional[List[str]] = None,
+        py_executable_override: Optional[str] = None,
     ) -> List[Dict[str, Any]]:
         """Returns modified runtime_envs with all local dirs converted to remote URIs.
 
@@ -137,6 +138,7 @@ class WorkloadSDK(BaseSDK):
                 return local_path_to_uri[target]
 
             self.logger.info(f"Uploading local dir '{target}' to cloud storage.")
+            assert cloud_id is not None
             uri = self._client.upload_local_dir_to_cloud_storage(
                 target, cloud_id=cloud_id, excludes=excludes,
             )
@@ -175,10 +177,13 @@ class WorkloadSDK(BaseSDK):
                     for py_module in final_py_modules
                 ]
 
+            if py_executable_override:
+                runtime_env["py_executable"] = py_executable_override
+
         return new_runtime_envs
 
     def _resolve_compute_config_id(
-        self, compute_config: Union[str, ComputeConfig]
+        self, compute_config: Union[str, ComputeConfig], cloud: Optional[str] = None,
     ) -> str:
         """Resolve the passed compute config to its ID.
 
@@ -190,7 +195,7 @@ class WorkloadSDK(BaseSDK):
         """
         if isinstance(compute_config, str):
             compute_config_id = self._client.get_compute_config_id(
-                compute_config_name=compute_config,
+                compute_config_name=compute_config, cloud=cloud,
             )
             if compute_config_id is None:
                 raise ValueError(
@@ -206,7 +211,7 @@ class WorkloadSDK(BaseSDK):
     def resolve_compute_config_and_cloud_id(
         self,
         *,
-        compute_config: Union[None, str, ComputeConfig],
+        compute_config: Union[ComputeConfig, Dict, str, None],
         cloud: Union[None, str],
     ) -> Tuple[str, str]:
         """Resolve the passed compute config to its ID and corresponding cloud ID.
@@ -225,14 +230,14 @@ class WorkloadSDK(BaseSDK):
                 self.client.get_cloud_id(compute_config_id=compute_config_id),
             )
         elif compute_config is None:
-            cloud_id = self.client.get_cloud_id(cloud_name=cloud)
+            cloud_id = self.client.get_cloud_id(cloud_name=cloud)  # type: ignore
             compute_config_id = self._client.get_default_compute_config(
                 cloud_id=cloud_id
             ).id
-            return (compute_config_id, cloud_id)
+            return (compute_config_id, cloud_id)  # type: ignore
         elif cloud is None:
             compute_config_id = self._resolve_compute_config_id(
-                compute_config=compute_config
+                compute_config=compute_config  # type: ignore
             )
             return (
                 compute_config_id,
@@ -247,12 +252,13 @@ class WorkloadSDK(BaseSDK):
                 compute_config = replace(compute_config, cloud=cloud)
 
             compute_config_id = self._resolve_compute_config_id(
-                compute_config=compute_config
+                compute_config=compute_config,  # type: ignore
+                cloud=cloud,
             )
             cloud_id_from_cc = self.client.get_cloud_id(
                 compute_config_id=compute_config_id
             )
-            cloud_id_from_cloud = self.client.get_cloud_id(cloud_name=cloud)
+            cloud_id_from_cloud = self.client.get_cloud_id(cloud_name=cloud)  # type: ignore
             if cloud_id_from_cc != cloud_id_from_cloud:
                 raise ValueError(
                     "Cloud does not match from provided `cloud` and `compute_config`. Either pass one of these or ensure they match."
@@ -265,7 +271,9 @@ class WorkloadSDK(BaseSDK):
         if not self._client.inside_workspace():
             return None
 
-        name = self._client.get_current_workspace_cluster().name
+        workspace = self._client.get_current_workspace_cluster()
+        assert workspace is not None
+        name = workspace.name
         # Defensively default to the workspace cluster name as-is if it doesn't
         # start with the expected prefix.
         if name.startswith(WORKSPACE_CLUSTER_NAME_PREFIX):
@@ -321,4 +329,6 @@ class WorkloadSDK(BaseSDK):
         if not compute_config.anonymous:
             return compute_config_name
 
-        return self._compute_config_sdk.get_compute_config(id=compute_config_id).config
+        return self._compute_config_sdk._convert_api_model_to_compute_config_version(  # noqa: SLF001
+            compute_config
+        ).config
