@@ -8,8 +8,8 @@ from typing import List, Optional
 from botocore.exceptions import ClientError
 import click
 import colorama
-from halo import Halo
 
+from anyscale.anyscale_halo import Halo
 from anyscale.client.openapi_client.models import (
     CloudAnalyticsEventCloudProviderError,
     CloudAnalyticsEventCloudResource,
