@@ -71,7 +71,7 @@ def compare_dicts_diff(d1: Dict[Any, Any], d2: Dict[Any, Any]) -> str:
     )
 
 
-AWS_RESOURCE_DICT: Dict[str, CloudAnalyticsEventCloudResource] = {
+AWS_RESOURCE_DICT: Dict[str, str] = {
     "VPC": CloudAnalyticsEventCloudResource.AWS_VPC,
     "Subnet": CloudAnalyticsEventCloudResource.AWS_SUBNET,
     "Security group": CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP,
