@@ -121,10 +121,13 @@ def get_job_submission_client_cluster_info(
 
     if len(cluster_list) > 0:
         cluster = cluster_list[0]
-        if cluster.host_name and cluster.access_token:
+        access_token = api_client.get_cluster_access_token_api_v2_authentication_cluster_id_cluster_access_token_get(
+            cluster_id=cluster.id
+        )
+        if cluster.host_name and access_token:
             return ClusterInfo(
                 address=cluster.host_name,
-                cookies={"anyscale-token": cluster.access_token},
+                cookies={"anyscale-token": access_token},
                 metadata=metadata,
             )
         else:
