@@ -1,22 +1,23 @@
 import re
-from typing import Optional, Tuple
+from typing import Optional, Tuple, Union
 
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.client.openapi_client.models import (
+    ComputeTemplateQuery,
+    CreateComputeTemplate,
+)
 from anyscale.cloud_utils import get_cloud_id_and_name, get_last_used_cloud
 from anyscale.sdk.anyscale_client import (
     ArchiveStatus,
     ComputeTemplateConfig,
-    CreateComputeTemplate,
 )
+from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as SDKDefaultApi
 from anyscale.sdk.anyscale_client.models.cluster_compute_config import (
     ClusterComputeConfig,
 )
 from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
-from anyscale.sdk.anyscale_client.models.compute_template_query import (
-    ComputeTemplateQuery,
-)
 from anyscale.utils.cloud_utils import get_organization_default_cloud
 
 
@@ -27,7 +28,7 @@ def get_default_cluster_compute(
     cloud_name: Optional[str],
     project_id: Optional[str],
     api_client: Optional[DefaultApi] = None,
-    anyscale_api_client: Optional[DefaultApi] = None,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
 ) -> ComputeTemplate:
     if api_client is None:
         api_client = get_auth_api_client().api_client
@@ -42,7 +43,7 @@ def get_default_cluster_compute(
             cloud_name = get_last_used_cloud(project_id, anyscale_api_client)
 
     cloud_id, _ = get_cloud_id_and_name(api_client, cloud_name=cloud_name)
-    config_object = anyscale_api_client.get_default_compute_config(cloud_id).result
+    config_object = anyscale_api_client.get_default_compute_config(cloud_id).result  # type: ignore
     compute_template = register_compute_template(config_object, api_client=api_client)
     return compute_template
 
@@ -87,14 +88,9 @@ def get_cluster_compute_from_name(
 
     version = None
 
-    enable_compute_config_versioning = api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-        "compute-config-versioning"
-    ).result.is_on
-
-    if enable_compute_config_versioning:
-        (cluster_compute_name, version,) = parse_cluster_compute_name_version(
-            cluster_compute_name
-        )
+    (cluster_compute_name, version,) = parse_cluster_compute_name_version(
+        cluster_compute_name
+    )
 
     cluster_computes = api_client.search_compute_templates_api_v2_compute_templates_search_post(
         ComputeTemplateQuery(
@@ -134,7 +130,7 @@ def register_compute_template(
 
 def get_selected_cloud_id_or_default(
     api_client: Optional[DefaultApi] = None,
-    anyscale_api_client: Optional[DefaultApi] = None,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
     cluster_compute_id: Optional[str] = None,
     cluster_compute_config: Optional[ClusterComputeConfig] = None,
     cloud_id: Optional[str] = None,
@@ -155,7 +151,7 @@ def get_selected_cloud_id_or_default(
             api_client=api_client, cloud_id=cloud_id, cloud_name=cloud_name,
         )
     elif cluster_compute_id:
-        parent_cloud_id = anyscale_api_client.get_cluster_compute(
+        parent_cloud_id = anyscale_api_client.get_cluster_compute(  # type: ignore
             cluster_compute_id
         ).result.config.cloud_id
     elif cluster_compute_config:
