@@ -4,7 +4,6 @@ Commands to interact with the Anyscale API
 
 import click
 
-from anyscale.commands.anyscale_api.session_commands_commands import session_commands
 from anyscale.commands.anyscale_api.session_operations_commands import (
     session_operations_commands,
 )
@@ -18,6 +17,5 @@ def anyscale_api() -> None:
     pass
 
 
-anyscale_api.add_command(session_commands)
 anyscale_api.add_command(sessions)
 anyscale_api.add_command(session_operations_commands)
