@@ -237,6 +237,7 @@ def cloud_config_group() -> None:
 @cloud_cli.command(
     name="update",
     help=(
+        # TODO(janet): Update this help text when the -o option is un-hidden.
         "Update a managed cloud to the latest configuration. Only applicable for anyscale managed clouds."
     ),
 )
@@ -275,7 +276,14 @@ def cloud_config_group() -> None:
         "are manually granted permissions to access the cloud. No existing cloud permissions are altered by specifying this flag."
     ),
 )
-def cloud_update(
+@click.option(
+    "--file",
+    "-f",
+    help="YAML file containing the updated cloud spec.",
+    required=False,
+    hidden=True,
+)
+def cloud_update(  # noqa: PLR0913
     cloud_name: Optional[str],
     name: Optional[str],
     cloud_id: Optional[str],
@@ -283,7 +291,12 @@ def cloud_update(
     enable_head_node_fault_tolerance: bool,
     yes: bool,
     enable_auto_add_user: Optional[bool],
+    file: Optional[str],
 ) -> None:
+    if file:
+        CloudController().update_cloud_deployments(file)
+        return
+
     if cloud_name and name and cloud_name != name:
         raise click.ClickException(
             "The positional argument CLOUD_NAME and the keyword argument --name "
@@ -423,7 +436,7 @@ def cloud_config_update(
     "--provider",
     help="The cloud provider type.",
     required=True,
-    type=click.Choice(["aws", "gcp", "generic"], case_sensitive=False),
+    type=click.Choice(["aws", "gcp", "azure", "generic"], case_sensitive=False),
 )
 @click.option(
     "--region",
@@ -848,18 +861,19 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
             skip_verifications=skip_verifications,
             auto_add_user=enable_auto_add_user,
         )
-    elif provider == "generic":
+    elif provider in ("azure", "generic"):
         # For the 'generic' provider type, for the time being, most fields are optional; only 'name', 'provider', and 'compute-stack' are required.
         if not name:
             raise click.ClickException("Please provide a value for --name.")
 
         if compute_stack != ComputeStack.K8S:
             raise click.ClickException(
-                "--compute-stack=k8s must be passed for registering generic Anyscale clouds."
+                "--compute-stack=k8s must be passed to register this Anyscale cloud."
             )
 
-        CloudController().register_generic_cloud(
+        CloudController().register_azure_or_generic_cloud(
             name=name,
+            provider=provider,
             auto_add_user=enable_auto_add_user,
             region=region,
             cloud_storage_bucket_name=cloud_storage_bucket_name,
@@ -1090,3 +1104,206 @@ def add_collaborators(cloud: str, users_file: str,) -> None:
     log.info(
         f"Successfully added {len(collaborators.collaborators)} collaborators to cloud {cloud}."
     )
+
+
+@cloud_cli.command(
+    name="get",
+    help="Get information about a specific cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_GET_CLOUD_EXAMPLE,
+)
+@click.option(
+    "--name",
+    "-n",
+    help="Name of the cloud to get information about.",
+    type=str,
+    required=False,
+)
+@click.option(
+    "--cloud-id",
+    "--id",
+    help="ID of the cloud to get information about.",
+    type=str,
+    required=False,
+)
+@click.option(
+    "--output",
+    "-o",
+    help="File to write the output YAML to.",
+    type=str,
+    required=False,
+)
+def get_cloud(
+    cloud_id: Optional[str], name: Optional[str], output: Optional[str]
+) -> None:
+    """
+    Retrieve a cloud by its name or ID and display its details.
+
+    :param cloud_id: The ID of the cloud to retrieve.
+    :param name: The name of the cloud to retrieve.
+    """
+    # Validate that exactly one of --name or --cloud-id is provided
+    if (cloud_id and name) or (not cloud_id and not name):
+        log.error("Please provide exactly one of --name or --cloud-id.")
+        return
+
+    try:
+        cloud = anyscale.cloud.get(id=cloud_id, name=name)
+
+        if not cloud:
+            log.error("Cloud not found.")
+            return
+
+        # Include all cloud deployments for the cloud.
+        cloud_deployments = CloudController().get_cloud_deployments(cloud_id=cloud.id)
+        result = {
+            "name": cloud.name,
+            "id": cloud.id,
+            "created_at": cloud.created_at,
+            "is_default": cloud.is_default,
+            "deployments": cloud_deployments.get("deployments", []),
+        }
+
+        if output:
+            with open(output, "w") as f:
+                yaml.dump(result, f, sort_keys=False)
+        else:
+            print(yaml.dump(result, sort_keys=False))
+
+    except ValueError as e:
+        log.error(f"Error retrieving cloud: {e}")
+
+
+@cloud_cli.command(
+    name="get-default",
+    help="Get the default cloud for your organization.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_GET_DEFAULT_CLOUD_EXAMPLE,
+)
+def get_default_cloud() -> None:
+    """
+    Retrieve and display the default cloud configured for your organization.
+    """
+    try:
+        default_cloud = anyscale.cloud.get_default()
+
+        if not default_cloud:
+            log.error("No default cloud found.")
+            return
+
+        cloud_dict = (
+            default_cloud.to_dict()
+            if hasattr(default_cloud, "to_dict")
+            else default_cloud.__dict__
+        )
+
+        print(yaml.dump(cloud_dict, sort_keys=False))
+
+    except ValueError as e:
+        log.error(f"Error retrieving default cloud: {e}")
+
+
+@cloud_cli.command(
+    name="jobs-report",
+    help=(
+        "Generate a report of the jobs created in the last 7 days in HTML format. "
+        "Shows unused CPU-hours, unused GPU-hours, and other data."
+    ),
+    cls=AnyscaleCommand,
+    hidden=True,
+)
+@click.option(
+    "--cloud-id",
+    help="ID of the cloud to generate a report on.",
+    type=str,
+    required=True,
+)
+@click.option(
+    "--csv",
+    help="Outputs the report in CSV format.",
+    type=bool,
+    required=False,
+    default=False,
+    is_flag=True,
+)
+@click.option(
+    "--out",
+    help="Output file name for the report. (Default jobs_report.html)",
+    type=str,
+    required=False,
+    default=None,
+)
+@click.option(
+    "--sort-by",
+    help=(
+        "Column to sort by. (Default created_at). "
+        "created_at: Job creation time. "
+        "gpu: Unused GPU hours. "
+        "cpu: Unused CPU hours. "
+        "instances: Number of instances."
+    ),
+    type=click.Choice(["created_at", "gpu", "cpu", "instances"], case_sensitive=False),
+    required=False,
+    default="created_at",
+)
+@click.option(
+    "--sort-order",
+    help="Sort order. (Default desc)",
+    type=click.Choice(["asc", "desc"], case_sensitive=False),
+    required=False,
+    default="desc",
+)
+def generate_jobs_report(
+    cloud_id: str, csv: bool, out: Optional[str], sort_by: str, sort_order: str
+) -> None:
+    """
+    Generate a report of the jobs created in the last 7 days in HTML format.
+    Shows unused CPU-hours, unused GPU-hours, and other data.
+    :param cloud_id: The ID of the cloud to generate a report on.
+    :param csv: Outputs the report in CSV format.
+    :param out: Output file name for the report.
+    """
+    if out is None:
+        out = "jobs_report.html" if not csv else "jobs_report.csv"
+
+    try:
+        CloudController().generate_jobs_report(
+            cloud_id, csv, out, sort_by, sort_order == "asc"
+        )
+    except ValueError as e:
+        log.error(f"Error generating jobs report: {e}")
+
+
+@cloud_cli.command(
+    name="terminate-system-cluster",
+    help="Terminate the system cluster for a specific given cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_TERMINATE_SYSTEM_CLUSTER_EXAMPLE,
+)
+@click.option(
+    "--cloud-id",
+    "--id",
+    help="ID of the cloud to terminate the system cluster for.",
+    type=str,
+    required=True,
+)
+@click.option(
+    "-w",
+    "--wait",
+    required=False,
+    default=False,
+    type=bool,
+    is_flag=True,
+    help="Block this CLI command and print logs until the job finishes.",
+)
+def terminate_system_cluster(cloud_id: str, wait: Optional[bool]) -> None:
+    """
+    Terminate the system cluster for a specific cloud.
+
+    :param cloud_id: The ID of the cloud to terminate the system cluster for.
+    :param wait: If True, wait for the system cluster to be terminated before returning. Defaults to False.
+    """
+    try:
+        anyscale.cloud.terminate_system_cluster(cloud_id, wait)
+    except ValueError as e:
+        log.error(f"Error terminating system cluster: {e}")
