@@ -1,4 +1,5 @@
 JOB_SUBMIT_EXAMPLE = """\
+# Submit a job without a yaml file, this will inherit the environment from the workspace.
 $ anyscale job submit --name my-job --wait -- python main.py
 Output
 (anyscale +1.0s) Submitting job with config JobConfig(name='my-job', image_uri=None, compute_config=None, env_vars=None, py_modules=None, cloud=None, project=None, ray_version=None, job_queue_config=None).
@@ -10,6 +11,27 @@ Output
 (anyscale +3.5s) Waiting for job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' to reach target state SUCCEEDED, currently in state: STARTING
 (anyscale +1m19.7s) Job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' transitioned from STARTING to SUCCEEDED
 (anyscale +1m19.7s) Job 'prodjob_6ntzknwk1i9b1uw1zk1gp9dbhe' reached target state, exiting
+
+# Submit a job specified by a yaml file, this will run a job with the specified settings.
+# See https://docs.anyscale.com/reference/job-api/#jobconfig for a list of all available fields.
+$ cat job.yaml
+name: my-job
+entrypoint: python main.py
+image_uri: anyscale/ray:2.44.1-slim-py312-cu128 # (Optional) Exclusive with `containerfile`.
+# compute_config: # (Optional) An inline dictionary can also be provided.
+#   head_node:
+#     instance_type: m5.8xlarge
+working_dir: . # (Optional) Use current working directory "." as the working_dir. Can be any local path or remote .zip file in cloud storage.
+requirements: # (Optional) List of requirements files to install. Can also be a path to a requirements.txt.
+  - emoji
+max_retries: 0 # (Optional) Maximum number of times the job will be retried before being marked failed. Defaults to `1`.
+$ anyscale job submit -f job.yaml
+Output
+(anyscale +1.0s) Submitting job with config JobConfig(name='my-job', image_uri='anyscale/ray:2.44.1-slim-py312-cu128', compute_config=None, env_vars=None, py_modules=None, py_executable=None, cloud=None, project=None, ray_version=None, job_queue_config=None).
+(anyscale +4.2s) Uploading local dir '.' to cloud storage.
+(anyscale +5.4s) Job 'my-job' submitted, ID: 'prodjob_ugk21r7pt6sbsxfuxn1an82x3e'.
+(anyscale +5.4s) View the job in the UI: https://console.anyscale.com/jobs/prodjob_ugk21r7pt6sbsxfuxn1an82x3e
+(anyscale +5.4s) Use `--wait` to wait for the job to run and stream logs.
 """
 
 JOB_STATUS_EXAMPLE = """\
@@ -55,6 +77,64 @@ NAME    ID                                    COST  PROJECT NAME    CLUSTER NAME
 my-job  prodjob_s9x4uzc5jnkt5z53g4tujb3y2e       0  default         cluster_for_prodjob_s9x4uzc5jnkt5z53g4tujb3y2e  SUCCESS                 doc@anyscale.com  python main.py
 """
 
+JOB_QUEUE_LIST = """\
+$ anyscale job-queue list
+Output
+JOB QUEUES:
+             ID                 NAME              CLUSTER ID                      CREATOR ID             MAX CONCURRENCY    IDLE TIMEOUT SEC    CURRENT CLUSTER STATE
+jq_h8fcze2qkr8wttuuvapi1hvyuc  queue_3  ses_cjr7uaf1yh2ue5uzvd11p24p4u  usr_we8x7d7u8hq8mj2488ed9x47n6          3                 5000               Terminated
+jq_v5bx9z1sd4pbxasxhdms37j4gi  queue_2  ses_k86raeu6k1t6z1bvyejn3vblad  usr_we8x7d7u8hq8mj2488ed9x47n6         10                 5000               Terminated
+jq_ni6hk66nt3194msr7hzzj9daun  queue_1  ses_uhb8a9gamtarz68kcurpjh86sa  usr_we8x7d7u8hq8mj2488ed9x47n6         10                 5000               Terminated
+"""
+
+JOB_QUEUE_INFO = """\
+$ anyscale job-queue info --id jq_h8fcze2qkr8wttuuvapi1hvyuc
+Output
+ID                            : jq_h8fcze2qkr8wttuuvapi1hvyuc
+USER PROVIDED ID              : queue_3
+NAME                          : queue_3
+CURRENT JOB QUEUE STATE       : ACTIVE
+EXECUTION MODE                : PRIORITY
+MAX CONCURRENCY               : 3
+IDLE TIMEOUT SEC              : 5000
+CREATED AT                    : 2025-04-15 20:40:44
+CREATOR ID                    : usr_we8x7d7u8hq8mj2488ed9x47n6
+CREATOR EMAIL                 : test@anyscale.com
+COMPUTE CONFIG ID             : cpt_8hzsv1t4jvb6kwjhfqbfjw5i6b
+CURRENT CLUSTER STATE         : Terminated
+CLUSTER ID                    : ses_cjr7uaf1yh2ue5uzvd11p24p4u
+PROJECT ID                    : prj_7FWKGPGPaD3Q5mvk9zK2viBD
+CLOUD ID                      : cld_kvedZWag2qA8i5BjxUevf5i7
+TOTAL JOBS                    : 6
+SUCCESSFUL JOBS               : 6
+FAILED JOBS                   : 0
+ACTIVE JOBS                   : 0
+"""
+
+JOB_QUEUE_UPDATE = """\
+$ anyscale job-queue update --id jq_h8fcze2qkr8wttuuvapi1hvyuc --max-concurrency 5
+Output
+ID                            : jq_h8fcze2qkr8wttuuvapi1hvyuc
+USER PROVIDED ID              : queue_3
+NAME                          : queue_3
+CURRENT JOB QUEUE STATE       : ACTIVE
+EXECUTION MODE                : PRIORITY
+MAX CONCURRENCY               : 5
+IDLE TIMEOUT SEC              : 5000
+CREATED AT                    : 2025-04-15 20:40:44
+CREATOR ID                    : usr_we8x7d7u8hq8mj2488ed9x47n6
+CREATOR EMAIL                 : test@anyscale.com
+COMPUTE CONFIG ID             : cpt_8hzsv1t4jvb6kwjhfqbfjw5i6b
+CURRENT CLUSTER STATE         : Terminated
+CLUSTER ID                    : ses_cjr7uaf1yh2ue5uzvd11p24p4u
+PROJECT ID                    : prj_7FWKGPGPaD3Q5mvk9zK2viBD
+CLOUD ID                      : cld_kvedZWag2qA8i5BjxUevf5i7
+TOTAL JOBS                    : 6
+SUCCESSFUL JOBS               : 6
+FAILED JOBS                   : 0
+ACTIVE JOBS                   : 0
+"""
+
 SCHEDULE_APPLY_EXAMPLE = """\
 $ anyscale schedule apply -n my-schedule -f my-schedule.yaml
 (anyscale +0.5s) Applying schedule with config ScheduleConfig(job_config=JobConfig(name='my-schedule', image_uri=None, compute_config=None, env_vars=None, py_modules=None, cloud=None, project=None, ray_version=None, job_queue_config=None), cron_expression='0 0 * * * *', timezone='UTC').
@@ -232,6 +312,16 @@ MACHINE POOL       ID                             Clouds
 can-testing        mp_8ogdz85mdwxb8a92yo44nn84ox
 """
 
+MACHINE_POOL_ATTACH_EXAMPLE = """\
+$ anyscale machine-pool attach --name can-testing --cloud my-cloud
+Attached machine pool 'can-testing' to cloud 'my-cloud'.
+"""
+
+MACHINE_POOL_DETACH_EXAMPLE = """\
+$ anyscale machine-pool detach --name can-testing --cloud my-cloud
+Detached machine pool 'can-testing' from cloud 'my-cloud'.
+"""
+
 LLM_MODELS_GET_EXAMPLE = """
 $ anyscale llm model get --model-id my-model-id
 Output
@@ -561,6 +651,59 @@ collaborators:
     permission_level: "readonly"
 """
 
+CLOUD_GET_CLOUD_EXAMPLE = """\
+$ anyscale cloud get --name my-cloud
+id: cld_123
+name: my-cloud
+created_at: 2022-10-18 05:12:13.335803+00:00
+is_default: true
+deployments:
+- cloud_deployment_id: cldrsrc_123
+  name: vm-aws-us-west-2
+  provider: AWS
+  compute_stack: VM
+  region: us-west-2
+  networking_mode: PUBLIC
+  object_storage:
+    bucket_name: s3://my-bucket
+  file_storage:
+    file_storage_id: fs-123
+  aws_config:
+    vpc_id: vpc-123
+    subnet_ids:
+    - subnet-123
+    security_group_ids:
+    - sg-123
+    anyscale_iam_role_id: arn:aws:iam::123456789012:role/anyscale-role-123
+    cluster_iam_role_id: arn:aws:iam::123456789012:role/cluster-role-123
+    memorydb_cluster_name: my-memorydb-cluster
+"""
+
+CLOUD_GET_DEFAULT_CLOUD_EXAMPLE = """\
+$ anyscale cloud get-default
+name: anyscale_v2_default_cloud
+id: cld_abc
+provider: AWS
+region: us-west-2
+created_at: 2022-10-18 05:12:13.335803+00:00
+is_default: true
+compute_stack: VM
+"""
+
+CLOUD_TERMINATE_SYSTEM_CLUSTER_EXAMPLE = """\
+$ anyscale cloud terminate-system-cluster --cloud-id cloud_id --wait
+(anyscale +1.3s) Waiting for system cluster termination............
+(anyscale +1m22.9s) System cluster for cloud 'cloud_id' is Terminated.
+"""
+
 SERVICE_ARCHIVE_EXAMPLE = """\
 $ anyscale service archive --name my_service
 """
+
+SERVICE_DELETE_EXAMPLE = """\
+$ anyscale service delete --name my_service
+"""
+
+SERVICE_LIST_EXAMPLE = """\
+$ anyscale service list --state running --sort -created_at
+"""
