@@ -93,7 +93,6 @@ def log_cli() -> None:
     pass
 
 
-# TODO (shomilj): Support environment variable for cluster ID here.
 @log_cli.command(name="cluster", help="Access log files of a cluster.")
 @click.option("--id", type=str, required=True, help="Provide a cluster ID.")
 @option_download
@@ -125,6 +124,39 @@ def anyscale_logs_cluster(  # noqa: PLR0913
     parallelism: int,
 ) -> None:
     logs_controller = LogsController()
+    execute_anyscale_logs_cluster(
+        logs_controller=logs_controller,
+        cluster_id=id,
+        download=download,
+        tail=tail,
+        glob=glob,
+        node_ip=node_ip,
+        instance_id=instance_id,
+        worker_only=worker_only,
+        head_only=head_only,
+        unpack=unpack,
+        ttl=ttl,
+        download_dir=download_dir,
+        parallelism=parallelism,
+    )
+
+
+def execute_anyscale_logs_cluster(  # noqa: PLR0913
+    logs_controller: LogsController,
+    cluster_id: str,
+    download: bool,
+    tail: int,
+    glob: Optional[str],
+    node_ip: Optional[str],
+    instance_id: Optional[str],
+    worker_only: bool,
+    head_only: bool,
+    unpack: bool,  # list files config
+    ttl: int,
+    # download files config
+    download_dir: Optional[str],
+    parallelism: int,
+):
 
     node_type: Optional[NodeType] = None
     if worker_only and head_only:
@@ -135,7 +167,7 @@ def anyscale_logs_cluster(  # noqa: PLR0913
         node_type = NodeType.HEAD_NODE
 
     filter = LogFilter(  # noqa: A001
-        cluster_id=id,
+        cluster_id=cluster_id,
         glob=glob,
         node_ip=node_ip,
         instance_id=instance_id,
@@ -221,6 +253,55 @@ def anyscale_logs_cluster(  # noqa: PLR0913
         click.echo()
 
 
+@log_cli.command(name="job", help="Access log files of a production job.")
+@click.option("--id", type=str, required=True, help="Provide a production job ID.")
+@option_download
+@option_tail
+@argument_glob
+@option_node_ip
+@option_instance_id
+@option_worker_only
+@option_head_only
+@option_unpack_combined_logs
+@option_download_dir
+@option_ttl
+@option_parallelism
+def anyscale_logs_job(  # noqa: PLR0913
+    id: str,  # noqa: A002
+    download: bool,
+    tail: int,
+    # filters
+    glob: Optional[str],
+    node_ip: Optional[str],
+    instance_id: Optional[str],
+    worker_only: bool,
+    head_only: bool,
+    unpack: bool,
+    # list files config
+    ttl: int,
+    # download files config
+    download_dir: Optional[str],
+    parallelism: int,
+) -> None:
+    logs_controller = LogsController()
+    cluster_id = logs_controller.get_cluster_id_for_last_prodjob_run(prodjob_id=id)
+    execute_anyscale_logs_cluster(
+        logs_controller=logs_controller,
+        cluster_id=cluster_id,
+        download=download,
+        tail=tail,
+        glob=glob,
+        node_ip=node_ip,
+        instance_id=instance_id,
+        worker_only=worker_only,
+        head_only=head_only,
+        unpack=unpack,
+        ttl=ttl,
+        download_dir=download_dir,
+        parallelism=parallelism,
+    )
+
+
 def convert_size(size_bytes):
     if size_bytes == 0:
         return "0B"
