@@ -1,15 +1,24 @@
 from io import StringIO
 from json import dumps as json_dumps
 import pathlib
-from typing import Any, Dict, Optional, Tuple
+import sys
+from typing import Any, Dict, List, Optional, Tuple
 
 import click
+from rich.console import Console
+from rich.table import Table
 from typing_extensions import Literal
 import yaml
 
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.cli_logger import BlockLogger
 from anyscale.commands import command_examples
+from anyscale.commands.list_util import (
+    display_list,
+    MAX_PAGE_SIZE,
+    NON_INTERACTIVE_DEFAULT_MAX_ITEMS,
+    validate_page_size,
+)
 from anyscale.commands.util import (
     AnyscaleCommand,
     convert_kv_strings_to_dict,
@@ -18,8 +27,21 @@ from anyscale.commands.util import (
 )
 from anyscale.controllers.service_controller import ServiceController
 import anyscale.service
-from anyscale.service import ServiceConfig, ServiceLogMode, ServiceState, ServiceStatus
-from anyscale.util import validate_non_negative_arg
+from anyscale.service.models import (
+    ServiceConfig,
+    ServiceLogMode,
+    ServiceSortField,
+    ServiceState,
+    ServiceStatus,
+    ServiceVersionStatus,
+    SortOrder,
+)
+from anyscale.util import (
+    AnyscaleJSONEncoder,
+    get_endpoint,
+    validate_non_negative_arg,
+    validate_service_state_filter,
+)
 
 
 log = BlockLogger()  # CLI Logger
@@ -96,7 +118,7 @@ def _read_name_from_config_file(path: str):
     required=False,
     default=None,
     type=str,
-    help="The Ray version (X.Y.Z) to the image specified by --image-uri. This is only used when --image-uri is provided. If not provided, the latest Ray version will be used.",
+    help="The Ray version (X.Y.Z) to the image specified by --image-uri. This is only used when --image-uri is provided. If you don't specify a Ray version, Anyscale defaults to the latest Ray version available at the time of the Anyscale CLI/SDK release.",
 )
 @click.option(
     "--compute-config",
@@ -142,7 +164,7 @@ def _read_name_from_config_file(path: str):
     required=False,
     default=None,
     type=int,
-    help="The percentage of traffic to send to the canary version of the service (0-100). This can be used to manually shift traffic toward (or away from) the canary version. If not provided, traffic will be shifted incrementally toward the canary version until it reaches 100. Not supported when using --in-place.",
+    help="The percentage of traffic to send to the canary version of the service (0-100). This can be used to manually shift traffic toward (or away from) the canary version. If not provided, traffic will be shifted incrementally toward the canary version until it reaches 100. Not supported when using --in-place. This is ignored when restarting a service or creating a new service.",
 )
 @click.option(
     "--max-surge-percent",
@@ -171,7 +193,7 @@ def _read_name_from_config_file(path: str):
     required=False,
     default=None,
     type=str,
-    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
 )
 @click.option(
     "--project",
@@ -334,7 +356,7 @@ def deploy(  # noqa: PLR0912, PLR0913 C901
     required=False,
     default=None,
     type=str,
-    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
 )
 @click.option(
     "--project",
@@ -388,12 +410,14 @@ def status(
         status_dict.get("primary_version", {}).pop("config", None)
         status_dict.get("canary_version", {}).pop("config", None)
 
+    console = Console()
     if json:
-        print(json_dumps(status_dict, indent=4, sort_keys=False))
+        json_str = json_dumps(status_dict, indent=2, cls=AnyscaleJSONEncoder)
+        console.print_json(json=json_str)
     else:
         stream = StringIO()
         yaml.dump(status_dict, stream, sort_keys=False)
-        print(stream.getvalue(), end="")
+        console.print(stream.getvalue(), end="")
 
 
 @service_cli.command(
@@ -415,7 +439,7 @@ def status(
     required=False,
     default=None,
     type=str,
-    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
 )
 @click.option(
     "--project",
@@ -481,7 +505,7 @@ def wait(
     required=False,
     default=None,
     type=str,
-    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
 )
 @click.option(
     "--project",
@@ -623,51 +647,259 @@ def rollout(  # noqa: PLR0913
     )
 
 
-# TODO(mowen): Add cloud support for this when we refactor to new SDK method
-@service_cli.command(name="list", help="Display information about services.")
+def validate_max_items(ctx, param, value):
+    if value is None:
+        return None
+    return validate_non_negative_arg(ctx, param, value)
+
+
+def _parse_sort_option(sort: Optional[str],) -> Tuple[Optional[str], SortOrder]:
+    """
+    Given a raw sort string (e.g. "-created_at"), return
+    (canonical_field_name, SortOrder).
+    """
+    if not sort:
+        return None, SortOrder.ASC
+
+    # build case-insensitive map of allowed fields
+    allowed = {f.value.lower(): f.value for f in ServiceSortField.__members__.values()}
+
+    # detect leading '-' for descending
+    if sort.startswith("-"):
+        raw = sort[1:]
+        order = SortOrder.DESC
+    else:
+        raw = sort
+        order = SortOrder.ASC
+
+    key = raw.lower()
+    if key not in allowed:
+        allowed_names = ", ".join(sorted(allowed.values()))
+        raise click.BadParameter(
+            f"Invalid sort field '{raw}'. Allowed fields: {allowed_names}"
+        )
+
+    return allowed[key], order
+
+
+def _create_service_list_table(show_header: bool) -> Table:
+    table = Table(show_header=show_header, expand=True)
+    # NAME and ID: larger ratios, can wrap but never truncate
+    table.add_column(
+        "NAME", no_wrap=False, overflow="fold", ratio=3, min_width=15,
+    )
+    table.add_column(
+        "ID", no_wrap=False, overflow="fold", ratio=2, min_width=12,
+    )
+    # all other columns will wrap as needed
+    for heading in (
+        "CURRENT STATE",
+        "CREATOR",
+        "PROJECT",
+        "LAST DEPLOYED AT",
+    ):
+        table.add_column(
+            heading, no_wrap=False, overflow="fold", ratio=1, min_width=8,
+        )
+
+    return table
+
+
+def _format_service_output_data(svc: ServiceStatus) -> Dict[str, str]:
+    last_deployed_at = ""
+    if isinstance(svc.primary_version, ServiceVersionStatus):
+        last_deployed_at = svc.primary_version.created_at.strftime("%Y-%m-%d %H:%M:%S")
+
+    return {
+        "name": svc.name,
+        "id": svc.id,
+        "current_state": str(svc.state),
+        "creator": str(svc.creator or ""),
+        "project": str(svc.project or ""),
+        "last_deployed_at": last_deployed_at,
+    }
+
+
+@service_cli.command(
+    name="list", help="List services.", cls=AnyscaleCommand,
+)
+@click.option("--service-id", "--id", help="ID of the service to display.")
+@click.option("--name", "-n", help="Name of the service to display.")
 @click.option(
-    "--name", "-n", required=False, default=None, help="Filter by service name."
+    "--cloud",
+    type=str,
+    help="The Anyscale Cloud of this workload; defaults to your org/workspace cloud.",
 )
 @click.option(
-    "--service-id", "--id", required=False, default=None, help="Filter by service id."
-)
-@click.option(
-    "--project-id", required=False, default=None, help="Filter by project id."
+    "--project",
+    type=str,
+    help="Named project to use; defaults to your org/workspace project.",
 )
 @click.option(
     "--created-by-me",
-    help="List services created by me only.",
     is_flag=True,
     default=False,
+    help="List services created by me only.",
+)
+@click.option(
+    "--state",
+    "-s",
+    "state_filter",
+    multiple=True,
+    callback=validate_service_state_filter,
+    help=(
+        "Filter by service state (repeatable). "
+        f"Allowed: {', '.join(s.value for s in ServiceState)}"
+    ),
+)
+@click.option(
+    "--include-archived",
+    is_flag=True,
+    default=False,
+    help="Include archived services.",
 )
 @click.option(
     "--max-items",
-    required=False,
-    default=10,
     type=int,
-    help="Max items to show in list.",
-    callback=validate_non_negative_arg,
+    callback=validate_max_items,
+    help="Max total items (only with --no-interactive).",
 )
-def list(  # noqa: A001
-    name: Optional[str],
+@click.option(
+    "--page-size",
+    type=int,
+    default=10,
+    show_default=True,
+    callback=validate_page_size,
+    help=f"Items per page (max {MAX_PAGE_SIZE}).",
+)
+@click.option(
+    "--interactive/--no-interactive",
+    default=True,
+    show_default=True,
+    help="Use interactive paging.",
+)
+@click.option(
+    "--sort",
+    help=(
+        "Sort by FIELD (prefix with '-' for desc). "
+        f"Allowed: {', '.join(f.value for f in ServiceSortField.__members__.values())}"
+    ),
+)
+@click.option(
+    "-v",
+    "--verbose",
+    is_flag=True,
+    default=False,
+    help="Include full config in JSON output.",
+)
+@click.option(
+    "-j",
+    "--json",
+    "json_output",
+    is_flag=True,
+    default=False,
+    help="Emit structured JSON to stdout.",
+)
+def list(  # noqa: PLR0913, A001
     service_id: Optional[str],
-    project_id: Optional[str],
+    name: Optional[str],
     created_by_me: bool,
-    max_items: int,
+    cloud: Optional[str],
+    project: Optional[str],
+    state_filter: List[str],
+    include_archived: bool,
+    max_items: Optional[int],
+    page_size: int,
+    sort: Optional[str],
+    json_output: bool,
+    interactive: bool,
+    verbose: bool,
 ):
-    """List services based on the provided filters.
+    """List services based on the provided filters."""
+    if max_items is not None and interactive:
+        raise click.UsageError("--max-items only allowed with --no-interactive")
 
-    This returns both v1 and v2 services.
-    """
-    service_controller = ServiceController()
-    service_controller.list(
-        name=name,
-        service_id=service_id,
-        project_id=project_id,
-        created_by_me=created_by_me,
-        max_items=max_items,
+    # parse sort
+    sort_field, sort_order = _parse_sort_option(sort)
+
+    # normalize max_items
+    effective_max = max_items
+    if not interactive and effective_max is None:
+        stderr = Console(stderr=True)
+        stderr.print(
+            f"Defaulting to {NON_INTERACTIVE_DEFAULT_MAX_ITEMS} items in batch mode; "
+            "use --max-items to override."
+        )
+        effective_max = NON_INTERACTIVE_DEFAULT_MAX_ITEMS
+
+    console = Console()
+    stderr = Console(stderr=True)
+
+    # diagnostics
+    stderr.print("[bold]Listing services with:[/]")
+    stderr.print(f"• name            = {name or '<any>'}")
+    stderr.print(f"• states          = {', '.join(state_filter) or '<all>'}")
+    stderr.print(f"• created_by_me   = {created_by_me}")
+    stderr.print(f"• include_archived= {include_archived}")
+    stderr.print(f"• sort            = {sort or '<none>'}")
+    stderr.print(f"• mode            = {'interactive' if interactive else 'batch'}")
+    stderr.print(f"• per-page limit  = {page_size}")
+    stderr.print(f"• max-items total = {effective_max or 'all'}")
+    stderr.print(f"\nView your Services in the UI at {get_endpoint('/services')}\n")
+
+    creator_id = (
+        ServiceController().get_authenticated_user_id() if created_by_me else None
     )
 
+    # choose formatter
+    if json_output:
+
+        def json_formatter(svc: ServiceStatus) -> Dict[str, Any]:
+            data = svc.to_dict()
+            if not verbose:
+                data.get("primary_version", {}).pop("config", None)
+                data.get("canary_version", {}).pop("config", None)
+            return data
+
+        formatter = json_formatter
+    else:
+        formatter = _format_service_output_data
+
+    total = 0
+    try:
+        iterator = anyscale.service.list(
+            service_id=service_id,
+            name=name,
+            state_filter=state_filter,
+            creator_id=creator_id,
+            cloud=cloud,
+            project=project,
+            include_archived=include_archived,
+            max_items=None if interactive else effective_max,
+            page_size=page_size,
+            sort_field=sort_field,
+            sort_order=sort_order,
+        )
+        total = display_list(
+            iterator=iter(iterator),
+            item_formatter=formatter,
+            table_creator=_create_service_list_table,
+            json_output=json_output,
+            page_size=page_size,
+            interactive=interactive,
+            max_items=effective_max,
+            console=console,
+        )
+
+        if not json_output:
+            if total > 0:
+                stderr.print(f"\nFetched {total} services.")
+            else:
+                stderr.print("\nNo services found.")
+    except Exception as e:  # noqa: BLE001
+        log.error(f"Failed to list services: {e}")
+        sys.exit(1)
+
 
 # TODO(mowen): Add cloud support for this when we refactor to new SDK method
 @service_cli.command(name="rollback", help="Roll back a service.")
@@ -707,7 +939,6 @@ def rollback(
     service_controller.rollback(service_id, max_surge_percent)
 
 
-# TODO(mowen): Add cloud support for this when we refactor to new SDK method
 @service_cli.command(name="terminate", help="Terminate a service.")
 @click.option(
     "--service-id", "--id", required=False, help="ID of service.",
@@ -730,6 +961,8 @@ def terminate(
 
     This applies to both v1 and v2 services.
     """
+    # TODO: Remove service_controller and use the sdk method. Need to update the sdk method
+    # so that it can resolve either service name or config file to the service id.
     service_controller = ServiceController()
     service_id = service_controller.get_service_id(
         service_id=service_id,
@@ -737,7 +970,14 @@ def terminate(
         service_config_file=config_file,
         project_id=project_id,
     )
-    service_controller.terminate(service_id)
+    try:
+        anyscale.service.terminate(id=service_id)
+        log.info(f"Service {service_id} terminate initiated.")
+        log.info(
+            f'View the service in the UI at {get_endpoint(f"/services/{service_id}")}'
+        )
+    except Exception as e:  # noqa: BLE001
+        log.error(f"Error terminating service: {e}")
 
 
 @service_cli.command(
@@ -747,22 +987,17 @@ def terminate(
     example=command_examples.SERVICE_ARCHIVE_EXAMPLE,
 )
 @click.option(
-    "-n", "--name", required=False, default=None, type=str, help="Name of the service.",
+    "--service-id", "--id", required=False, help="ID of service.",
 )
 @click.option(
-    "-f",
-    "--config-file",
-    required=False,
-    default=None,
-    type=str,
-    help="Path to a YAML config file to read the name from.",
+    "-n", "--name", required=False, default=None, type=str, help="Name of the service.",
 )
 @click.option(
     "--cloud",
     required=False,
     default=None,
     type=str,
-    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used.",
 )
 @click.option(
     "--project",
@@ -772,27 +1007,66 @@ def terminate(
     help="Named project to use for the service. If not provided, the default project for the cloud will be used (or, if running in a workspace, the project of the workspace).",
 )
 def archive(
+    service_id: Optional[str],
     name: Optional[str],
-    config_file: Optional[str],
     cloud: Optional[str],
     project: Optional[str],
 ) -> None:
-    """Archive a service.
+    """Archive a service."""
 
-    To specify the service by name, use the --name flag. To specify the service by id, use the --id flag. Either name or
-id should be used, specifying both will result in an error.
-    """
-    if name is not None and config_file is not None:
-        raise click.ClickException(
-            "Only one of '--name' and '--config-file' can be provided."
-        )
+    if (service_id and name) or (not service_id and not name):
+        log.error("Exactly one of '--id/--service-id' or '--name' must be provided.")
+        sys.exit(1)
 
-    if config_file is not None:
-        name = _read_name_from_config_file(config_file)
+    identifier = name if name else service_id
+    try:
+        anyscale.service.archive(id=service_id, name=name, cloud=cloud, project=project)
+        log.info(f"Successfully archived service: {identifier}")
+    except Exception as e:  # noqa: BLE001
+        log.error(f"Error archiving service: {e}")
 
-    if name is None:
-        raise click.ClickException(
-            "Service name must be provided using '--name' or in a config file using '-f'."
-        )
 
-    anyscale.service.archive(name=name, cloud=cloud, project=project)
+@service_cli.command(
+    name="delete",
+    help="Delete a service.",
+    cls=AnyscaleCommand,
+    example=command_examples.SERVICE_DELETE_EXAMPLE,
+)
+@click.option(
+    "--service-id", "--id", required=False, help="ID of service.",
+)
+@click.option(
+    "-n", "--name", required=False, default=None, type=str, help="Name of the service.",
+)
+@click.option(
+    "--cloud",
+    required=False,
+    default=None,
+    type=str,
+    help="The Anyscale Cloud of this workload. If not provided, the organization default will be used.",
+)
+@click.option(
+    "--project",
+    required=False,
+    default=None,
+    type=str,
+    help="Named project to use for the service. If not provided, the default project for the cloud will be used (or, if running in a workspace, the project of the workspace).",
+)
+def delete(
+    service_id: Optional[str],
+    name: Optional[str],
+    cloud: Optional[str],
+    project: Optional[str],
+) -> None:
+    """Delete a service"""
+
+    if (service_id and name) or (not service_id and not name):
+        log.error("Exactly one of '--id/--service-id' or '--name' must be provided.")
+        sys.exit(1)
+
+    identifier = name if name else service_id
+    try:
+        anyscale.service.delete(id=service_id, name=name, cloud=cloud, project=project)
+        log.info(f"Successfully deleted service: {identifier}")
+    except Exception as e:  # noqa: BLE001
+        log.error(f"Error deleting service: {e}")
