@@ -4,7 +4,11 @@ from typing import Optional
 
 import click
 
-from anyscale.project import get_project_id, get_project_session, load_project_or_throw
+from anyscale.project_utils import (
+    get_project_id,
+    get_project_session,
+    load_project_or_throw,
+)
 from anyscale.shared_anyscale_utils.util import execution_log_name
 from anyscale.snapshot import copy_file
 from anyscale.util import deserialize_datetime, send_json_request
@@ -166,7 +170,7 @@ def session_finish_command(command_id: str, stop: bool, terminate: bool) -> None
 @click.option(
     "--session-id", help="The session id of this web terminal", type=str, required=True,
 )
-def web_terminal_server(  # noqa: PLR0913
+def web_terminal_server(
     deploy_environment: str,
     use_debugger: bool,
     cli_token: str,
