@@ -8,8 +8,7 @@ from packaging import version
 
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client.models.build import Build
-from anyscale.client.openapi_client.models.session import Session
+from anyscale.client.openapi_client.models import Build, CreateComputeTemplate, Session
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_selected_cloud_id_or_default,
@@ -19,7 +18,6 @@ from anyscale.links import DOCS_CLUSTER
 from anyscale.sdk.anyscale_client import (
     ComputeTemplateConfig,
     CreateCluster,
-    CreateComputeTemplate,
     StartClusterOptions,
     UpdateCluster,
 )
@@ -56,6 +54,7 @@ BUILD_STEPS = [
 # Default minutes for autosuspend.
 DEFAULT_AUTOSUSPEND_TIMEOUT = 120
 
+
 # Default docker images to use for connect clusters.
 def _get_base_image(image: str, ray_version: str, cpu_or_gpu: str) -> str:
     py_version = "".join(str(x) for x in sys.version_info[0:2])
@@ -275,11 +274,21 @@ class PrepareClusterBlock:
             # Try to generate an auto-incrementing cluster name from the first 100 clusters.
             # If there are more than 40 clusters with, we will generate a random name.
             # If the name is already taken, we will re-try with a different random name.
-            results = list_entities(
-                self.anyscale_api_client.list_sessions, project_id, max=100
-            )
+            used_names: List[str] = []
+            has_more = True
+            paging_token = None
+            while has_more:
+                resp = self.anyscale_api_client.search_clusters(
+                    clusters_query={
+                        "project_id": project_id,
+                        "paging": {"count": 50, "paging_token": paging_token},
+                    }
+                )
+                used_names.extend([c.name for c in resp.results])
+                paging_token = resp.metadata.next_paging_token
+                has_more = paging_token is not None
+
             self.log.debug("-> Starting a new cluster")
-            used_names = [s.name for s in results]
             for i in range(MAX_CLUSTERS):
                 name = f"cluster-{i}"
                 if name not in used_names:
@@ -547,34 +556,36 @@ class PrepareClusterBlock:
         """
         Get the default cluster env build based on the local python and ray versions.
         """
-        py_version = "".join(str(x) for x in sys.version_info[0:2])
-        if sys.version_info.major == 3 and sys.version_info.minor == 10:
-            py_version = "310"
-        if py_version not in ["36", "37", "38", "39", "310"]:
+        major, minor = sys.version_info[:2]
+        MIN_PY_VER = (3, 8)
+        MAX_PY_VER = (3, 12)
+
+        if not (MIN_PY_VER <= (major, minor) <= MAX_PY_VER):
             raise ValueError(
-                "No default cluster env for py{}. Please use a version of python between 3.6 and 3.8.".format(
-                    py_version
-                )
+                f"No default container image for python version {major}.{minor}."
+                f"Please use a Python version between {MIN_PY_VER[0]}.{MIN_PY_VER[1]} "
+                f"and {MAX_PY_VER[0]}.{MAX_PY_VER[1]}."
             )
+
         ray_version = self._ray.__version__
         if version.parse(ray_version) < version.parse(MINIMUM_RAY_VERSION):
             raise ValueError(
-                f"No default cluster env for Ray version {ray_version}. Please upgrade "
+                f"No default container image for Ray version {ray_version}. Please upgrade "
                 f"to a version >= {MINIMUM_RAY_VERSION}."
             )
         if "dev0" in ray_version:
             raise ValueError(
                 f"Your locally installed Ray version is {ray_version}. "
-                "There is no default cluster environments for nightly versions of Ray."
+                "There is no default container image for nightly versions of Ray."
             )
         try:
             build = self.api_client.get_default_cluster_env_build_api_v2_builds_default_py_version_ray_version_get(
-                f"py{py_version}", ray_version
+                f"py{major}{minor}", ray_version
             ).result
             return build
         except Exception:  # noqa: BLE001
             raise RuntimeError(
-                f"Failed to get default cluster env for Ray: {ray_version} on Python: py{py_version}"
+                f"Failed to get default container image for Ray: {ray_version} on Python: py{major}{minor}"
             )
 
     def _get_cluster_build(
@@ -805,14 +816,16 @@ class PrepareClusterBlock:
         return compute_template_id
 
     def _register_compute_template(
-        self, project_id: str, config_object: ComputeTemplateConfig
+        self, project_id: str, config_object: ComputeTemplateConfig  # noqa: ARG002
     ) -> str:
         """
-        Register compute template with a default name and return the compute template id."""
+        Register compute template with a default name and return the compute template id.
+        """
         created_template = self.api_client.create_compute_template_api_v2_compute_templates_post(
             create_compute_template=CreateComputeTemplate(
                 name=gen_valid_name("autogenerated-config"),
-                project_id=project_id,
+                # project ID is deprecated in compute config
+                project_id=None,
                 config=config_object,
                 anonymous=True,
             )
