@@ -358,22 +358,18 @@ class ClusterController(BaseController):
                         project_id = get_project_id(project_definition.root)
                     except click.ClickException:
                         parent_cloud_id = None
-                        feature_flag_on = self.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-                            "cloud-isolation-phase-1"
-                        ).result.is_on
                         log_msg = "No project context detected or `--project-id` provided. Continuing without a project."
-                        if feature_flag_on:
-                            if not (cloud_id or cloud_name):
-                                cloud_name = get_last_used_cloud(
-                                    project_id=None,
-                                    anyscale_api_client=self.anyscale_api_client,
-                                )
-                            parent_cloud_id, _ = get_cloud_id_and_name(
-                                api_client=self.api_client,
-                                cloud_id=cloud_id,
-                                cloud_name=cloud_name,
+                        if not (cloud_id or cloud_name):
+                            cloud_name = get_last_used_cloud(
+                                project_id=None,
+                                anyscale_api_client=self.anyscale_api_client,
                             )
-                            log_msg = f"No project context detected or `--project-id` provided. Continuing without a project assuming cloud {parent_cloud_id}."
+                        parent_cloud_id, _ = get_cloud_id_and_name(
+                            api_client=self.api_client,
+                            cloud_id=cloud_id,
+                            cloud_name=cloud_name,
+                        )
+                        log_msg = f"No project context detected or `--project-id` provided. Continuing without a project assuming cloud {parent_cloud_id}."
                         default_project = self.anyscale_api_client.get_default_project(
                             parent_cloud_id=parent_cloud_id
                         ).result
@@ -480,18 +476,11 @@ class ClusterController(BaseController):
                 "`--cloud-name` and `--cloud-id` cannot both be specified. Please only provide one "
                 "of these two arguments."
             )
-        feature_flag_on = self.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-            "cloud-isolation-phase-1"
-        ).result.is_on
-        if (
-            feature_flag_on
-            and cluster_name is not None
-            and (
-                project_id is None
-                and project_name is None
-                and cloud_id is None
-                and cloud_name is None
-            )
+        if cluster_name is not None and (
+            project_id is None
+            and project_name is None
+            and cloud_id is None
+            and cloud_name is None
         ):
             raise click.ClickException(
                 "Please specify the project of the cluster through `--project-id` or `--project-name`. If the cluster "
@@ -533,6 +522,7 @@ class ClusterController(BaseController):
                 api_client=self.api_client,
                 anyscale_api_client=self.anyscale_api_client,
             )
+            assert project_id is not None
             cluster_name = self._get_or_generate_cluster_name(project_id, cluster_name)
         return project_id, cluster_name
 
