@@ -91,6 +91,29 @@ class ClusterEnvController(BaseController):
         # TODO(nikita): Improve formatting here
         print(config)
 
+    def archive(
+        self, cluster_env_name: Optional[str], cluster_env_id: Optional[str]
+    ) -> None:
+        if int(cluster_env_name is not None) + int(cluster_env_id is not None) != 1:
+            raise click.ClickException(
+                "Please only provide one of `--name` or `--cluster-env-id`."
+            )
+
+        if cluster_env_id:
+            cluster_env_name = self.anyscale_api_client.get_cluster_environment(
+                cluster_env_id
+            ).result.name
+        elif cluster_env_name:
+            cluster_env_id = get_cluster_env_from_name(
+                cluster_env_name, self.anyscale_api_client
+            ).id
+        assert cluster_env_id  # for mypy
+
+        self.api_client.archive_cluster_environment_api_v2_application_templates_application_template_id_archive_post(
+            cluster_env_id
+        )
+        self.log.info(f"Successfully archived cluster environment: {cluster_env_name}.")
+
     def _list_cluster_envs(self, include_shared: bool, max_items: int) -> None:
         """
         Lists cluster environments (not including builds).
