@@ -3,7 +3,7 @@ from typing import Optional
 import click
 
 from anyscale.cli_logger import BlockLogger
-from anyscale.cloud import get_cloud_id_and_name
+from anyscale.cloud_utils import get_cloud_id_and_name
 from anyscale.controllers.base_controller import BaseController
 
 
