@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import os
 import random
@@ -80,7 +82,7 @@ class JobController(BaseController):
         log: Optional[LogsLogger] = None,
         initialize_auth_api_client: bool = True,
         raise_structured_exception: bool = False,
-        auth_token: str = None,
+        auth_token: Optional[str] = None,
     ):
         if log is None:
             log = LogsLogger()
@@ -294,7 +296,7 @@ class JobController(BaseController):
         project_id: Optional[str],
         include_archived: bool,
         max_items: int,
-        states: List[str],
+        states: List[HaJobStates],
     ) -> None:
         """
         This function will list jobs.
@@ -338,6 +340,7 @@ class JobController(BaseController):
                 )
             else:
                 creator_id = None
+
             resp = self.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get(
                 project_id=project_id,
                 name=name,
@@ -647,3 +650,7 @@ class JobController(BaseController):
             ),
         )
         return job_runs
+
+    def get_authenticated_user_id(self) -> str:
+        user_info_response = self.api_client.get_user_info_api_v2_userinfo_get()
+        return user_info_response.result.id
