@@ -178,7 +178,8 @@ def verify_gcp_project(  # noqa: PLR0911
 
     # Verify that APIs are Enabled
     service_usage_client = factory.build("serviceusage", "v1")
-    if resources.memorystore_instance_config is not None:
+    enable_memorystore_api = resources.memorystore_instance_config is not None
+    if enable_memorystore_api:
         apis = GCP_REQUIRED_APIS + ["redis.googleapis.com"]  # Memorystore for Redis
     else:
         apis = GCP_REQUIRED_APIS
@@ -217,7 +218,9 @@ def verify_gcp_project(  # noqa: PLR0911
 
     # enable all required apis, the operation is idompotent
     try:
-        enable_project_apis(factory, project_id, logger.internal)
+        enable_project_apis(
+            factory, project_id, logger.internal, enable_memorystore_api
+        )
     except ClickException as e:
         logger.internal.error(e.message)
         logger.spinner.text = spinner_text
