@@ -73,15 +73,16 @@ job_queue_spec:
         elif idle_timeout_s < 0:
             raise ValueError("'idle_timeout_s' should be >= 0")
 
-    name: str = field(
+    name: Optional[str] = field(
+        default=None,
         metadata={
             "docstring": "Name of the job queue that can be used to target it when submitting future jobs. "
             "The name of a job queue must be unique within a project.",
         },
     )
 
-    def _validate_name(self, name: str):
-        if not isinstance(name, str):
+    def _validate_name(self, name: Optional[str]):
+        if name is not None and not isinstance(name, str):
             raise TypeError(f"'name' must be a string (it is {type(name)}).")
 
     execution_mode: JobQueueExecutionMode = field(  # type: ignore
@@ -132,6 +133,26 @@ job_queue_spec:
                 f"'max_concurrency' must be an int (it is {type(max_concurrency)})."
             )
 
+    auto_termination_threshold_job_count: Optional[int] = field(
+        default=None,
+        metadata={
+            "docstring": "Maximum number of jobs the cluster can run before it "
+            "becomes eligible for termination"
+        },
+    )
+
+    def _validate_auto_termination_threshold_job_count(
+        self, auto_termination_threshold_job_count: Optional[int]
+    ):
+        if auto_termination_threshold_job_count is None:
+            return
+        if not isinstance(auto_termination_threshold_job_count, int):
+            raise TypeError(
+                f"'auto_termination_threshold_job_count' must be an int (it is {type(auto_termination_threshold_job_count)})."
+            )
+        if auto_termination_threshold_job_count <= 0:
+            raise ValueError("'auto_termination_threshold_job_count' should be > 0")
+
 
 @dataclass(frozen=True)
 class JobQueueConfig(ModelBase):
@@ -487,6 +508,14 @@ state: STARTING
             if not isinstance(run, JobRunStatus):
                 raise TypeError("Each run in 'runs' must be a JobRunStatus.")
 
+    creator_id: str = field(
+        metadata={"docstring": "ID of the user who created the job.",},
+    )
+
+    def _validate_creator_id(self, creator_id: str):
+        if creator_id is not None and not isinstance(creator_id, str):
+            raise TypeError("'creator_id' must be a string.")
+
 
 class JobLogMode(ModelEnum):
     """Mode to use for getting job logs."""
