@@ -29,7 +29,7 @@ class ProjectSDK:
     )
     def add_collaborators(  # noqa: F811
         self, cloud: str, project: str, collaborators: List[CreateProjectCollaborator],
-    ) -> str:
+    ) -> None:
         """Batch add collaborators to a project.
         """
-        return self._private_sdk.add_collaborators(cloud, project, collaborators)
+        self._private_sdk.add_collaborators(cloud, project, collaborators)
