@@ -11,11 +11,11 @@ from anyscale.project.models import CreateProjectCollaborator
 class PrivateProjectSDK(BaseSDK):
     def add_collaborators(
         self, cloud: str, project: str, collaborators: List[CreateProjectCollaborator]
-    ) -> str:
+    ) -> None:
         cloud_id = self.client.get_cloud_id(cloud_name=cloud, compute_config_id=None)
         project_id = self.client.get_project_id(parent_cloud_id=cloud_id, name=project)
 
-        return self.client.add_project_collaborators(
+        self.client.add_project_collaborators(
             project_id=project_id,
             collaborators=[
                 CreateUserProjectCollaborator(
