@@ -22,6 +22,7 @@ from anyscale.commands.experimental_integrations_commands import (
 )
 from anyscale.commands.image_commands import image_cli
 from anyscale.commands.job_commands import job_cli
+from anyscale.commands.job_queue_commands import job_queue_cli
 from anyscale.commands.list_commands import list_cli
 from anyscale.commands.llm.group import llm_cli
 from anyscale.commands.login_commands import anyscale_login, anyscale_logout
@@ -42,6 +43,7 @@ from anyscale.commands.user_commands import user_cli
 from anyscale.commands.workspace_commands import workspace_cli
 from anyscale.commands.workspace_commands_v2 import workspace_cli as workspace_cli_v2
 import anyscale.conf
+import anyscale.telemetry  # IMPORTANT: auto-patches click instrumentation on import
 from anyscale.utils.cli_version_check_util import log_warning_if_version_needs_upgrade
 
 
@@ -120,6 +122,7 @@ cli.add_command(version_cli)
 cli.add_command(list_cli)
 cli.add_command(cluster_env_cli)
 cli.add_command(job_cli)
+cli.add_command(job_queue_cli)
 cli.add_command(schedule_cli)
 cli.add_command(service_cli)
 cli.add_command(cluster_cli)
@@ -153,6 +156,7 @@ ALIASES = {
     "h": anyscale_help,
     "schedules": schedule_cli,
     "jobs": job_cli,
+    "jq": job_queue_cli,
     "services": service_cli,
     "cluster-compute": compute_config_cli,
     "images": image_cli,
