@@ -68,7 +68,7 @@ def _upload_and_rewrite_working_dir_in_create_production_job(create_production_j
 
 def _upload_and_rewrite_working_dir_ray_serve_config(
     ray_serve_config: Optional[Dict[str, Any]]
-) -> Dict[str, Any]:
+) -> Optional[Dict[str, Any]]:
     """
     If a local working_dir and upload_path are specified, this method
     will upload the working_dir and rewrites the working_dir to the remote uri.
@@ -159,7 +159,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         poll_rate_seconds: int = 15,
         timeout_seconds: Optional[int] = None,
         log_output: bool = False,
-    ) -> ClusterEnvironmentBuild:
+    ) -> Optional[ClusterEnvironmentBuild]:
         """
         Creates a new Cluster Environment and waits for build to complete.
 
@@ -199,7 +199,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                 correct_base_image_name = get_correct_name_for_base_image_name(base_image_name)
                 if base_image_name != correct_base_image_name: # We need to make sure base_image_name after ray 2.7.0, before 2.8.0 have a optimized suffix
                     self.log.error(f"Starting from Ray version 2.7.0 and before version 2.8.0, you might be required to include the suffix 'optimized' in the base_image name for that specific Ray version. Try using {self.log.highlight(correct_base_image_name)}")
-                    return
+                    return  # type: ignore
                 cluster_environment = self.create_cluster_environment(
                     create_cluster_environment
                 ).result
@@ -224,7 +224,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                 correct_base_image_name = get_correct_name_for_base_image_name(base_image_name)
                 if base_image_name != correct_base_image_name: # We need to make sure base_image_name after ray 2.7.0, before 2.8.0 have a optimized suffix
                     self.log.error(f"Starting from Ray version 2.7.0 and before version 2.8.0, you might be required to include the suffix 'optimized' in the base_image name for that specific Ray version. Try using {self.log.highlight(correct_base_image_name)}")
-                    return
+                    return  # type: ignore
                 build = self.create_cluster_environment_build(
                     {
                         "cluster_environment_id": cluster_environment.id,
@@ -477,6 +477,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             create_cluster_environment, poll_rate_seconds, timeout_seconds
         )
 
+        assert cluster_environment_build is not None
         return self.launch_cluster(
             project_id,
             cluster_name,
