@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from anyscale._private.sdk import sdk_command
 from anyscale.user._private.user_sdk import PrivateUserSDK
@@ -35,8 +35,10 @@ _ADMIN_BATCH_CREATE_ARG_DOCSTRINGS = {
     arg_docstrings=_ADMIN_BATCH_CREATE_ARG_DOCSTRINGS,
 )
 def admin_batch_create(
-    admin_create_users: List[AdminCreateUser], *, _sdk: PrivateUserSDK
+    admin_create_users: List[AdminCreateUser],
+    *,
+    _private_sdk: Optional[PrivateUserSDK] = None
 ) -> List[AdminCreatedUser]:
     """Batch create, as an admin, users without email verification.
     """
-    return _sdk.admin_batch_create(admin_create_users)
+    return _private_sdk.admin_batch_create(admin_create_users)  # type: ignore
