@@ -37,7 +37,10 @@ from anyscale.authenticate import get_auth_api_client
 from anyscale.aws_iam_policies import ANYSCALE_IAM_POLICIES, AnyscaleIAMPolicy
 from anyscale.cli_logger import BlockLogger, CloudSetupLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi as ProductApi
-from anyscale.client.openapi_client.models import AWSMemoryDBClusterConfig
+from anyscale.client.openapi_client.models import (
+    AWSMemoryDBClusterConfig,
+    ServiceEventCurrentState,
+)
 from anyscale.client.openapi_client.models.cloud_analytics_event_cloud_resource import (
     CloudAnalyticsEventCloudResource,
 )
@@ -127,6 +130,15 @@ MEMORY_DB_RESOURCE = """  MemoryDBSubnetGroup:
 GCP_DEPLOYMENT_MANAGER_TIMEOUT_SECONDS_LONG = 600  # 10 minutes
 
 
+class AnyscaleJSONEncoder(json.JSONEncoder):
+    """Custom JSON encoder for Anyscale models, handling datetime objects."""
+
+    def default(self, obj):
+        if isinstance(obj, datetime.datetime):
+            return obj.isoformat()
+        return json.JSONEncoder.default(self, obj)
+
+
 def confirm(msg: str, yes: bool) -> Optional[bool]:
     return None if yes else click.confirm(msg, abort=True)
 
@@ -623,6 +635,28 @@ def validate_non_negative_arg(ctx, param, value):  # noqa: ARG001
     return value
 
 
+def validate_service_state_filter(
+    ctx, param, value: Tuple[str, ...]  # noqa: ARG001
+) -> List[str]:
+    """Validate ServiceEventCurrentState values."""
+    if not value:
+        return []
+
+    allowable_values_upper = {
+        s.upper() for s in ServiceEventCurrentState.allowable_values
+    }
+    allowed_values_str = ", ".join(ServiceEventCurrentState.allowable_values)
+
+    for state_str in value:
+        state_upper = state_str.upper()
+        if state_upper not in allowable_values_upper:
+            raise click.ClickException(
+                f"'{state_str}' is not a valid value for {param.opts[0]}. Allowed values: {allowed_values_str}"
+            )
+
+    return [s.upper() for s in value]
+
+
 def _update_external_ids_for_policy(
     original_policy: Dict[str, Any], new_external_id: str
 ):
@@ -987,7 +1021,9 @@ def validate_job_config_dict(
         )
 
 
-def validate_list_jobs_state_filter(ctx, param, value) -> List[str]:  # noqa: ARG001
+def validate_list_jobs_state_filter(
+    _, param, value
+) -> List[HaJobStates]:  # noqa: ARG001
     """
     Validate the job state filter for list jobs CLI method
     """
