@@ -15,6 +15,7 @@ from typing import (
     Optional,
     Tuple,
     TYPE_CHECKING,
+    Union,
 )
 from urllib.parse import urlparse
 
@@ -31,6 +32,7 @@ from anyscale.client.openapi_client.models.cloud_with_cloud_resource_gcp import
     CloudWithCloudResourceGCP,
 )
 from anyscale.client.openapi_client.models.user_info import UserInfo
+from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as SDKDefaultApi
 from anyscale.shared_anyscale_utils.aws import bucket_name_from_maybe_bucket_arn
 from anyscale.util import is_anyscale_workspace
 from anyscale.utils.ray_utils import zip_directory  # type: ignore
@@ -221,7 +223,7 @@ def upload_and_rewrite_working_dir(
 
 def override_runtime_env_config(
     runtime_env: Optional[Dict[str, Any]],
-    anyscale_api_client: DefaultApi,
+    anyscale_api_client: Union[DefaultApi, SDKDefaultApi],
     api_client: DefaultApi,
     workload_type: Workload,
     compute_config_id: Optional[str],
