@@ -113,7 +113,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         name = config.name
 
         compute_config_id, cloud_id = self.resolve_compute_config_and_cloud_id(
-            compute_config=config.compute_config, cloud=config.cloud,
+            compute_config=config.compute_config, cloud=config.cloud,  # type: ignore
         )
 
         project_id = self.client.get_project_id(
@@ -292,7 +292,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
                 f"Workspace '{workspace_id_or_name}' did not reach target state {state} within {timeout_s}s. Last seen state: {curr_state}."
             )
 
-    def _get_workspace_status(self, workspace_id: str) -> WorkspaceState:
+    def _get_workspace_status(self, workspace_id: Optional[str]) -> WorkspaceState:
 
         cluster = self.client.get_workspace_cluster(workspace_id)
         if not cluster:
@@ -422,11 +422,18 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             should_warn_delete = True
             dry_run_options.append("--delete-excluded")
 
-        result = subprocess.run(
-            rsync_command + dry_run_options, capture_output=True, text=True, check=True
-        )
-        if result.returncode != 0:
-            raise RuntimeError(f"Rsync failed with return code {result.returncode}")
+        try:
+            result = subprocess.run(
+                rsync_command + dry_run_options,
+                capture_output=True,
+                text=True,
+                check=True,
+            )
+        except subprocess.CalledProcessError as e:
+            self._logger.error(f"Error running rsync command: {e}")
+            self._logger.error(f">>> stdout: {e.stdout}")
+            self._logger.error(f">>> stderr: {e.stderr}")
+            raise RuntimeError(f"Rsync failed with return code {e.returncode}")
 
         _, deleting_files = self._parse_rsync_dry_run_output(result.stdout)
 
@@ -514,7 +521,13 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             # Add -v / --verbose to the rsync command to be explicit about what is being transferred
             args += ["-v"]
 
-            subprocess.run(args, check=True)
+            try:
+                subprocess.run(args, check=True, capture_output=True, text=True)
+            except subprocess.CalledProcessError as e:
+                self._logger.error(f">>> Error running rsync command: {e}")
+                self._logger.error(f">>> stdout: {e.stdout}")
+                self._logger.error(f">>> stderr: {e.stderr}")
+                raise RuntimeError(f"Rsync failed with return code {e.returncode}")
 
     def pull(
         self,
@@ -564,8 +577,10 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             delete=delete,
         )
 
-    def update(self, *, id: str, config: UpdateWorkspaceConfig) -> str:  # noqa: A002
-        workspace = self.client.get_workspace(id=id)
+    def update(
+        self, *, id: Optional[str], config: UpdateWorkspaceConfig  # noqa: A002
+    ) -> str:
+        workspace = self.client.get_workspace(id=id)  # type: ignore
 
         if not workspace:
             raise ValueError(f"Workspace with id '{id}' was not found.")
@@ -581,7 +596,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         compute_config_id = None
         if config.compute_config:
             compute_config_id, _ = self.resolve_compute_config_and_cloud_id(
-                compute_config=config.compute_config, cloud=None,
+                compute_config=config.compute_config, cloud=None,  # type: ignore
             )
 
         build_id = None
@@ -642,14 +657,14 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             )
             self._logger.info(f"Applied environment variables to workspace id: {id}")
 
-        return id
+        return id  # type: ignore
 
     def _convert_cluster_state_to_workspace_state(
         self, state: SessionState
     ) -> WorkspaceState:
         return cast(
             WorkspaceState,
-            self._BACKEND_SESSION_STATE_TO_WORKSPACE_STATE.get(
+            self._BACKEND_SESSION_STATE_TO_WORKSPACE_STATE.get(  # type: ignore
                 state, WorkspaceState.UNKNOWN
             ),
         )
